@@ -2,7 +2,7 @@
 # The LearningOnline Network
 # CrGrant.pl  - Grant a loncapa SSL certificate.
 #
-# $Id: CrGrant.pl,v 1.5 2004/07/09 09:16:09 foxr Exp $
+# $Id: CrGrant.pl,v 1.6 2009/02/17 21:18:07 schafran Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -440,18 +440,18 @@ sub CreateEmail {
 	die "Unable to create top level MIME Message";
     }
 
-     $mime_message->attach(Data =>["  This email contains your lonCAPA SSL certificates.  These\n",
+     $mime_message->attach(Data =>["  This e-mail contains your lonCAPA SSL certificates.  These\n",
      "certificates allow your system to interact with the world wide\n",
      "cluster of LonCAPA systems, and allow you to access and share\n",
      "public resources for courses you host.\n\n",
      "   The certificates are shipped as a self installing shell script\n",
      "To install these certificates:\n\n",
-     "1. Extract the attachment to this email message\n",
+     "1. Extract the attachment to this e-mail message\n",
      "2. Save the attachment where it can be recovered in case you need\n",
      "   to re-install these certificates later on for some reason\n",
      "3. As root execute the certificate request file:
            . $installer_file\n",
-     "   (Note: If you used a Windows based email program to extract the\n",
+     "   (Note: If you used a Windows based e-mail program to extract the\n",
      "   this file and then tranferred it to your unix lonCAPA system you \n",
      "   Will probably need to convert the file first e.g.: \n",
      "     dos2unix $installer_file\n",
