@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Cookie Based Access Handler
 #
-# $Id: lonacc.pm,v 1.159.2.1 2015/03/11 17:27:15 raeburn Exp $
+# $Id: lonacc.pm,v 1.159.2.5 2017/01/21 20:40:46 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -109,7 +109,6 @@ sub cleanup {
     my ($r)=@_;
     if (! $r->is_initial_req()) { return DECLINED; }
     &Apache::lonnet::save_cache();
-    &Apache::lontexconvert::jsMath_reset();
     return OK;
 }
 
@@ -332,10 +331,24 @@ sub sso_login {
         }
         unless ($hosthere) {
             ($is_balancer,$otherserver) =
-                &Apache::lonnet::check_loadbalancing($user,$domain);
+                &Apache::lonnet::check_loadbalancing($user,$domain,'login');
+            if ($is_balancer) {
+                if ($otherserver eq '') {
+                    my $lowest_load;
+                    ($otherserver,undef,undef,undef,$lowest_load) = &Apache::lonnet::choose_server($domain);
+                    if ($lowest_load > 100) {
+                        $otherserver = &Apache::lonnet::spareserver($lowest_load,$lowest_load,1,$domain);
+                    }
+                }
+                if ($otherserver ne '') {
+                    my @hosts = &Apache::lonnet::current_machine_ids();
+                    if (grep(/^\Q$otherserver\E$/,@hosts)) {
+                        $hosthere = $otherserver;
+                    }
+                }
+            }
         }
-
-	if ($is_balancer) {
+	if (($is_balancer) && (!$hosthere)) {
 	    # login but immediately go to switch server to find us a new 
 	    # machine
 	    &Apache::lonauth::success($r,$user,$domain,$home,'noredirect');
@@ -353,14 +366,7 @@ sub sso_login {
 	} else {
 	    # need to login them in, so generate the need data that
 	    # migrate expects to do login
-	    my $ip;
-	    my $c = $r->connection;
-	    eval {
-	        $ip = $c->remote_ip();
-	    };
-	    if ($@) {
-	        $ip = $c->client_ip();
-	    }
+            my $ip = $r->get_remote_host();
 	    my %info=('ip'        => $ip,
 		      'domain'    => $domain,
 		      'username'  => $user,
@@ -384,6 +390,9 @@ sub sso_login {
                 $info{'sso.reloginserver'} = 
                     $r->dir_config('lonSSOReloginServer'); 
             }
+            if (($is_balancer) && ($hosthere)) {
+                $info{'noloadbalance'} = $hosthere;
+            }
 	    my $token = 
 		&Apache::lonnet::tmpput(\%info,
 					$r->dir_config('lonHostID'));
@@ -606,6 +615,12 @@ sub handler {
                             return HTTP_NOT_ACCEPTABLE;
                         }
                     }
+                } elsif (($handle =~ /^publicuser_\d+$/) && (&Apache::lonnet::is_portfolio_url($requrl))) {
+                    my $clientip = $r->get_remote_host();
+                    if (&Apache::lonnet::allowed('bre',$requrl,undef,undef,$clientip) ne 'F') {
+                        $env{'user.error.msg'}="$requrl:bre:1:1:Access Denied";
+                        return HTTP_NOT_ACCEPTABLE;
+                    }
                 } else {
 		    $env{'user.error.msg'}="$requrl:bre:1:1:Access Denied";
 		    return HTTP_NOT_ACCEPTABLE;
@@ -744,7 +759,8 @@ sub handler {
     }
 # ------------------------------------ See if this is a viewable portfolio file
     if (&Apache::lonnet::is_portfolio_url($requrl)) {
-	my $access=&Apache::lonnet::allowed('bre',$requrl);
+        my $clientip = $r->get_remote_host();
+	my $access=&Apache::lonnet::allowed('bre',$requrl,undef,undef,$clientip);
 	if ($access eq 'A') {
 	    &Apache::restrictedaccess::setup_handler($r);
 	    return OK;
