@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Login Screen
 #
-# $Id: lonlogin.pm,v 1.158.2.3 2015/03/06 22:45:30 raeburn Exp $
+# $Id: lonlogin.pm,v 1.158.2.6 2016/08/13 20:11:58 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -353,11 +353,7 @@ lextkey=this.document.client.elements.lextkey.value;
 initkeys();
 
 this.document.server.elements.upass0.value
-    =crypted(this.document.client.elements.upass$now.value.substr(0,15));
-this.document.server.elements.upass1.value
-    =crypted(this.document.client.elements.upass$now.value.substr(15,15));
-this.document.server.elements.upass2.value
-    =crypted(this.document.client.elements.upass$now.value.substr(30,15));
+    =getCrypted(this.document.client.elements.upass$now.value);
 
 this.document.client.elements.uname.value='';
 this.document.client.elements.upass$now.value='';
@@ -388,9 +384,20 @@ ENDSCRIPT
 	       alink        => "$alink",
                onload       => 'javascript:enableInput();',);
 
-    my %defaultdomconf = &Apache::loncommon::get_domainconf($defdom);
-    my $headextra = $defaultdomconf{$defdom.'.login.headtag_'.$lonhost};
-    my $headextra_exempt = $defaultdomconf{$domain.'.login.headtag_exempt_'.$lonhost};
+    my ($lonhost_in_use,$headextra,$headextra_exempt,@hosts,%defaultdomconf);
+    @hosts = &Apache::lonnet::current_machine_ids();
+    $lonhost_in_use = $lonhost;
+    if (@hosts > 1) {
+        foreach my $hostid (@hosts) {
+            if (&Apache::lonnet::host_domain($hostid) eq $defdom) {
+                $lonhost_in_use = $hostid;
+                last;
+            }
+        }
+    }
+    %defaultdomconf = &Apache::loncommon::get_domainconf($defdom);
+    $headextra = $defaultdomconf{$defdom.'.login.headtag_'.$lonhost_in_use};
+    $headextra_exempt = $defaultdomconf{$domain.'.login.headtag_exempt_'.$lonhost_in_use};
     if ($headextra) {
         my $omitextra;
         if ($headextra_exempt ne '') {
@@ -402,7 +409,7 @@ ENDSCRIPT
         }
         unless ($omitextra) {
             my $confname = $defdom.'-domainconfig';
-            if ($headextra =~ m{^\Q/res/$defdom/$confname/login/headtag/$lonhost/\E}) {
+            if ($headextra =~ m{^\Q/res/$defdom/$confname/login/headtag/$lonhost_in_use/\E}) {
                 my $extra = &Apache::lonnet::getfile(&Apache::lonnet::filelocation("",$headextra));
                 unless ($extra eq '-1') {
                     $js .= "\n".$extra."\n";
@@ -461,8 +468,6 @@ ENDSCRIPT
    <input type="hidden" name="serverid" value="$lonhost" />
    <input type="hidden" name="uname" value="" />
    <input type="hidden" name="upass0" value="" />
-   <input type="hidden" name="upass1" value="" />
-   <input type="hidden" name="upass2" value="" />
    <input type="hidden" name="udom" value="" />
    <input type="hidden" name="localpath" value="$env{'form.localpath'}" />
    <input type="hidden" name="localres" value="$env{'form.localres'}" />
@@ -513,7 +518,7 @@ LFORM
         $r->print(<<HEADER);
 <!-- The LON-CAPA Header -->
 <div style="background:$pgbg;margin:0;width:100%;">
-  <img src="$img" border="0" alt="The Learning Online Network with CAPA" />
+  <img src="$img" border="0" alt="The Learning Online Network with CAPA" class="LC_maxwidth" />
 </div>
 HEADER
     }
@@ -537,7 +542,7 @@ HEADER
 <div>
 ENDTOP
     if ($showmainlogo) {
-        $r->print(' <img src="'.$logo.'" alt="" />'."\n");
+        $r->print(' <img src="'.$logo.'" alt="" class="LC_maxwidth" />'."\n");
     }
 $r->print(<<ENDTOP);
 $announcements
