@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Starts a user off based of an existing token.
 #
-# $Id: migrateuser.pm,v 1.24 2014/10/07 03:13:34 raeburn Exp $
+# $Id: migrateuser.pm,v 1.25 2016/12/05 00:51:43 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -252,6 +252,9 @@ sub handler {
     if ($data{'iptoken'} ne '') {
         $form{'iptoken'} = $data{'iptoken'};
     }
+    if ($data{'noloadbalance'} ne '') {
+        $form{'noloadbalance'} = $data{'noloadbalance'};
+    }
 
     if (!$data{'role'}) {
 	my $handle = &Apache::lonnet::check_for_valid_session($r);
