@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Cookie Based Access Handler
 #
-# $Id: publiccheck.pm,v 1.23 2013/12/13 02:10:27 raeburn Exp $
+# $Id: publiccheck.pm,v 1.24.2.1 2017/06/06 22:37:18 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -70,7 +70,7 @@ sub handler {
     } elsif (&Apache::lonnet::is_portfolio_url($requrl)) {
 	my (undef,$udom,$unum,$file_name,$group) = 
 	    &Apache::lonnet::parse_portfolio_url($requrl);
-        my $access = &process_portfolio($udom,$unum,$file_name,$group);
+        my $access = &process_portfolio($r,$udom,$unum,$file_name,$group);
         if ($access) {
             &process_public($r,$requrl,$access);
             return OK;
@@ -92,7 +92,7 @@ sub process_public {
         my $cookie=&Apache::lonauth::success($r,'public','public','public');
         my $lonidsdir=$r->dir_config('lonIDsDir');
         &Apache::lonnet::transfer_profile_to_env($lonidsdir,$cookie);
-	$r->err_header_out('Set-cookie',"lonID=$cookie; path=/");
+	$r->err_header_out('Set-cookie',"lonID=$cookie; path=/; HttpOnly");
     }
     &Apache::lonacc::get_posted_cgi($r);
     $env{'request.state'} = "published";
@@ -102,11 +102,12 @@ sub process_public {
 }
 
 sub process_portfolio {
-    my ($udom,$unum,$file_name,$group) = @_;
+    my ($r,$udom,$unum,$file_name,$group) = @_;
     my $current_perms = &Apache::lonnet::get_portfile_permissions($udom,$unum);
     my %access_controls = &Apache::lonnet::get_access_controls($current_perms,$group,$file_name);
     my $access = '';
     my $now = time;
+    my $clientip = $r->get_remote_host();
     foreach my $key (keys(%{$access_controls{$file_name}})) {
         my ($num,$scope,$end,$start) = ($key =~ /^([^:]+):([a-z]+)_(\d*)_?(\d*)$/);
         if ($start > $now) {
@@ -119,6 +120,16 @@ sub process_portfolio {
             $access = 'public';
             last;
         }
+        if ($scope eq 'ip') {
+            if (ref($access_controls{$file_name}{$key}) eq 'HASH') {
+                if (ref($access_controls{$file_name}{$key}{'ip'}) eq 'ARRAY') {
+                    if (&Apache::loncommon::check_ip_acc(join(',',@{$access_controls{$file_name}{$key}{'ip'}}),$clientip)) {
+                        $access = 'ip';
+                        last;
+                    }
+                }
+            }
+        }
         if ($scope eq 'guest') {
             $access = 'guest';
         }
