@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Switch Servers Handler
 #
-# $Id: switchserver.pm,v 1.34 2015/01/22 22:45:06 raeburn Exp $
+# $Id: switchserver.pm,v 1.35 2016/12/16 15:31:11 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -112,12 +112,12 @@ sub handler {
     my $skip_canhost_check = '';
     if ($env{'form.role'}) {
         if (!exists($env{'user.role.'.$env{'form.role'}})) {
-            return FORBIDDEN;
+            delete($env{'form.role'});
         } else {
             my $now = time;
             my ($start,$end) = split(/\./,$env{'user.role.'.$env{'form.role'}});
             if (($start && $start > $now) || ($end && $end < $now)) {
-                return FORBIDDEN;
+                delete($env{'form.role'});
             } elsif ($env{'form.role'} eq 'au./'.$env{'user.domain'}.'/') {
                 if (&Apache::lonnet::homeserver($env{'user.name'},$env{'user.domain'}) eq $env{'form.otherserver'}) {
                     $skip_canhost_check = 1;
