@@ -2,7 +2,7 @@
 #
 # Automated Course Creation script
 #
-# $Id: Autocreate.pl,v 1.19 2011/03/07 02:10:40 raeburn Exp $
+# $Id: Autocreate.pl,v 1.20 2016/11/16 18:09:21 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -165,7 +165,7 @@
 
 sub process_xml {
     my ($fh,$dom,$dcname,$dcdom) = @_;
-    &set_dc_env($dcname.$dcdom,$dom);
+    &set_dc_env($dcname,$dcdom,$dom);
     # Initialize language handler
     &Apache::lonlocal::get_language_handle();
 
