@@ -1,7 +1,7 @@
 #
 # LON-CAPA helpers for cgi-bin scripts
 #
-# $Id: loncgi.pm,v 1.13 2013/05/13 01:26:54 raeburn Exp $
+# $Id: loncgi.pm,v 1.14 2014/10/14 19:54:00 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -246,6 +246,9 @@ sub cgi_header {
     if ($contenttype ne '') {
         if ($mimetypes->type($contenttype) ne '') {
             $headers{'-type'} = $contenttype;
+            if ($contenttype =~ m{^text/}) {
+                $headers{'-charset'} = 'utf-8';
+            }
         }
     }
     if ($nocache) {
