@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # caparesponse definition
 #
-# $Id: caparesponse.pm,v 1.255 2014/12/30 20:03:15 raeburn Exp $
+# $Id: caparesponse.pm,v 1.258 2016/08/09 23:43:45 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -642,12 +642,7 @@ sub end_numericalresponse {
 		}
 	    }
 	}
-        if (($target eq 'web') && ($tag eq 'formularesponse')
-            && ($Apache::lonhomework::type ne 'exam') && ($Apache::inputtags::status['-1'] eq 'CAN_ANSWER')
-	    && (&Apache::lonnet::EXT('resource.'.$partid.'_'.$id.'.turnoffeditor') ne 'yes')) {
-            $result.=&Apache::response::edit_mathresponse_button($partid,$id);
-        }
-            
+
 	&Apache::response::setup_prior_tries_hash(\&format_prior_response_numerical);
     } elsif ($target eq 'edit') {
 	$result.='</td></tr>'.&Apache::edit::end_table;
@@ -795,7 +790,10 @@ sub end_numericalresponse {
 						    $tag,$parstack,
 						    $safeeval,1);
 		    $error=&mt("Computer's answer is incorrect ([_1]).",'"'.join(', ',@$response).'"').' ';
-		    if ($sigline ne '') {
+                    if ($ad eq 'UNIT_INVALID_STUDENT') {
+                        $error.=&mt('Unable to interpret units. Computer reads units as "[_1]".',$msg).' '.
+                                &mt('The unit attribute in the numericalresponse item needs to be a supported physical unit.');
+		    } elsif ($sigline ne '') {
 			$error.=&mt('It is likely that the tolerance range [_1] or significant figures [_2] need to be adjusted.',$tolline,$sigline);
 		    } else {
 			$error.=&mt('It is likely that the tolerance range [_1] needs to be adjusted.',$tolline);
@@ -896,7 +894,7 @@ sub get_table_sizes {
     my $cell_width=0;
     foreach my $member (@$rbubble_values) {
 	my $cell_width_real=0;
-	if ($member=~/(\+|-)?(\d*)\.?(\d*)\s*\$?\\times\s*10\^{(\+|-)?(\d+)}\$?/) {
+	if ($member=~/(\+|-)?(\d*)\.?(\d*)\s*\$?\\times\s*10\^\{(\+|-)?(\d+)}\$?/) {
 	    $cell_width_real=(length($2)+length($3)+length($5)+7)*$scale;
 	} elsif ($member=~/(\d*)\.?(\d*)(E|e)(\+|-)?(\d*)/) {
 	    $cell_width_real=(length($1)+length($2)+length($5)+9)*$scale;
