@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA 
 # edit mode helpers
 #
-# $Id: edit.pm,v 1.152 2014/11/28 18:23:03 raeburn Exp $
+# $Id: edit.pm,v 1.153 2015/01/19 15:35:53 goltermann Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -164,12 +164,9 @@ sub tag_start {
 	    $description=&mt(&Apache::lonxml::description($token));
 	    if (!$description) { $description="&lt;$tag&gt;"; }
 	}
-	$result.= &start_table($token)."<tr><td>$description</td>
-                      <td>".&mt('Delete?').' '.
-		      &deletelist($target,$token)
-		      ."</td>
-                       <td>".
-		       &insertlist($target,$token);
+    $result.= &start_table($token)."<tr><td>".&Apache::loncommon::insert_folding_button().
+        " $description</td><td>".&mt('Delete?')." ".&deletelist($target,$token).
+        "</td><td>".&insertlist($target,$token);
 #<td>". 
 #  &movebuttons($target,$token).
 #    "</tr><tr><td colspan=\"3\">\n";
@@ -232,7 +229,10 @@ sub end_table {
     return $result;
 }
 
-sub start_spanning_row { return '<tr><td colspan="5" bgcolor="#F0F0F0">';}
+sub start_spanning_row {
+    return '<tr name="foldblock_'.$Apache::lonxml::curdepth.
+    '" style="visibility: \'\'"><td colspan="5" bgcolor="#F0F0F0">';
+}
 sub start_row          { return '<tr><td bgcolor="#DDDDDD">';            }
 sub end_row            { return '</td></tr>';          }
 
@@ -788,12 +788,14 @@ sub element_change_detection {
 
 sub submit_ask_anyway {
     my ($extra_action) = @_;
-    return ' onclick="still_ask=true;'.$extra_action.'" ';
+    my $resource = $env{'request.ambiguous'};
+    return ' onclick="saveScrollPosition(\''.$resource.'\');still_ask=true;'.$extra_action.';" ';
 }
 
 sub submit_dont_ask {
     my ($extra_action) = @_;
-    return ' onclick="is_submit=true;'.$extra_action.'" ';
+    my $resource = $env{'request.ambiguous'};
+    return ' onclick="saveScrollPosition(\''.$resource.'\');is_submit=true;'.$extra_action.';" ';
 }
 
 sub js_update_linknum {
