@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # The LON-CAPA Homework handler
 #
-# $Id: lonhomework.pm,v 1.344.2.2 2015/04/20 01:22:58 raeburn Exp $
+# $Id: lonhomework.pm,v 1.344.2.8 2017/04/03 13:11:47 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -208,12 +208,12 @@ sub proctor_checked_in {
 }
 
 sub check_slot_access {
-    my ($id,$type)=@_;
+    my ($id,$type,$symb,$partlist)=@_;
 
     # does it pass normal muster
-    my ($status,$datemsg)=&check_access($id);
+    my ($status,$datemsg)=&check_access($id,$symb);
     
-    my $useslots = &Apache::lonnet::EXT("resource.0.useslots");
+    my $useslots = &Apache::lonnet::EXT("resource.0.useslots",$symb);
     if ($useslots ne 'resource' && $useslots ne 'map' 
 	&& $useslots ne 'map_map') {
 	return ($status,$datemsg);
@@ -237,8 +237,8 @@ sub check_slot_access {
 	}
     }
 
-    my $availablestudent = &Apache::lonnet::EXT("resource.0.availablestudent");
-    my $available = &Apache::lonnet::EXT("resource.0.available");
+    my $availablestudent = &Apache::lonnet::EXT("resource.0.availablestudent",$symb);
+    my $available = &Apache::lonnet::EXT("resource.0.available",$symb);
     my @slots= (split(':',$availablestudent),split(':',$available));
 
 #    if (!@slots) {
@@ -248,6 +248,9 @@ sub check_slot_access {
     my ($returned_slot,$slot_name);
     my $now = time;
     my $num_usable_slots = 0;
+    unless ($symb) {
+        ($symb) = &Apache::lonnet::whichuser();
+    }
     foreach my $slot (@slots) {
 	$slot =~ s/(^\s*|\s*$)//g;
 	&Apache::lonxml::debug("getting $slot");
@@ -271,9 +274,10 @@ sub check_slot_access {
 	$slotstatus=$status;
     }
 
-    my ($is_correct,$got_grade,$checkedin);
+    my ($is_correct,$got_grade,$checkin,$checkinslot,$checkedin,$consumed_uniq);
     if ($type eq 'Task') {
 	my $version=$Apache::lonhomework::history{'resource.0.version'};
+        $checkin = "resource.$version.0.checkedin";
 	$got_grade = 
 	    ($Apache::lonhomework::history{"resource.$version.0.status"} 
 	     =~ /^(?:pass|fail)$/);
@@ -283,10 +287,57 @@ sub check_slot_access {
 	$checkedin =
 	    $Apache::lonhomework::history{"resource.$version.0.checkedin"};
     } elsif ($type eq 'problem') {
-	$got_grade  = 1;
-	$checkedin  = $Apache::lonhomework::history{"resource.0.checkedin"};
-	$is_correct =
-	    ($Apache::lonhomework::history{"resource.0.solved"} =~/^correct_/);
+        $checkin = 'resource.0.checkedin';
+	$checkedin  = $Apache::lonhomework::history{$checkin};
+    }
+    if ($checkedin) {
+        $checkinslot = $Apache::lonhomework::history{"$checkin.slot"};
+        my %slot=&Apache::lonnet::get_slot($checkinslot);
+        $consumed_uniq = $slot{'uniqueperiod'};
+    }
+    if ($type eq 'problem') {
+        if ((ref($partlist) eq 'ARRAY') && (@{$partlist} > 0)) {
+            my ($numcorrect,$numgraded) = (0,0);
+            foreach my $part (@{$partlist}) {
+                my $currtries = $Apache::lonhomework::history{"resource.$part.tries"};
+                my $maxtries = &Apache::lonnet::EXT("resource.$part.maxtries",$symb);
+                my $probstatus = &Apache::structuretags::get_problem_status($part);
+                my $earlyout;
+                unless (($probstatus eq 'no') ||
+                        ($probstatus eq 'no_feedback_ever')) {
+                    if ($Apache::lonhomework::history{"resource.$part.solved"} =~/^correct_/) {
+                        $numcorrect ++;
+                    } else {
+                        $earlyout = 1;
+                    }
+                }
+                if (($currtries == $maxtries) || ($is_correct)) {
+                    $earlyout = 1;
+                } else {
+                    $numgraded ++;
+                }
+                last if ($earlyout);
+            }
+            my $numparts = scalar(@{$partlist});
+            if ($numparts == $numcorrect) {
+                $is_correct = 1;
+            }
+            if ($numparts == $numgraded) {
+                $got_grade = 1;
+            }
+        } else {
+            my $currtries = $Apache::lonhomework::history{"resource.0.tries"};
+            my $maxtries = &Apache::lonnet::EXT("resource.0.maxtries",$symb);
+            my $probstatus = &Apache::structuretags::get_problem_status('0');
+            unless (($probstatus eq 'no') ||
+                    ($probstatus eq 'no_feedback_ever')) {
+                $is_correct =
+                    ($Apache::lonhomework::history{"resource.0.solved"} =~/^correct_/);
+            }
+            unless (($currtries == $maxtries) || ($is_correct)) {
+                $got_grade = 1;
+            }
+        }
     }
     
     &Apache::lonxml::debug(" slot is $slotstatus checkedin ($checkedin) got_grade ($got_grade) is_correct ($is_correct)");
@@ -310,22 +361,63 @@ sub check_slot_access {
                 if ($env{'request.course.id'}) {
                     my $cdom = $env{'course.'.$env{'request.course.id'}.'.domain'};
                     my $cnum = $env{'course.'.$env{'request.course.id'}.'.num'};
-                    my ($symb)=&Apache::lonnet::whichuser();
                     $slotstatus = 'NOTRESERVABLE';
                     my ($reservable_now_order,$reservable_now,$reservable_future_order,
                         $reservable_future) = 
                         &Apache::loncommon::get_future_slots($cnum,$cdom,$now,$symb);
                     if ((ref($reservable_now_order) eq 'ARRAY') && (ref($reservable_now) eq 'HASH')) {
                         if (@{$reservable_now_order} > 0) {
-                            $slotstatus = 'RESERVABLE';
-                            $datemsg = $reservable_now->{$reservable_now_order->[-1]}{'endreserve'};
+                            if ((!$checkedin) || (ref($consumed_uniq) ne 'ARRAY')) {
+                                $slotstatus = 'RESERVABLE';
+                                $datemsg = $reservable_now->{$reservable_now_order->[-1]}{'endreserve'};
+                            } else {
+                                my ($uniqstart,$uniqend,$useslot);
+                                if (ref($consumed_uniq) eq 'ARRAY') {
+                                    ($uniqstart,$uniqend)=@{$consumed_uniq};
+                                }
+                                foreach my $slot (reverse(@{$reservable_now_order})) {
+                                    if ($reservable_now->{$slot}{'uniqueperiod'} =~ /^(\d+)\,(\d+)$/) {
+                                        my ($new_uniq_start,$new_uniq_end) = ($1,$2);
+                                        next if (!
+                                            ($uniqstart < $new_uniq_start && $uniqend < $new_uniq_start) ||
+                                            ($uniqstart > $new_uniq_end   &&  $uniqend > $new_uniq_end  ));
+                                    }
+                                    $useslot = $slot;
+                                    last;
+                                }
+                                if ($useslot) {
+                                    $slotstatus = 'RESERVABLE';
+                                    $datemsg = $reservable_now->{$useslot}{'endreserve'};
+                                }
+                            }
                         }
                     }
                     unless ($slotstatus eq 'RESERVABLE') {
                         if ((ref($reservable_future_order) eq 'ARRAY') && (ref($reservable_future) eq 'HASH')) {
                             if (@{$reservable_future_order} > 0) {
-                                $slotstatus = 'RESERVABLE_LATER';
-                                $datemsg = $reservable_future->{$reservable_future_order->[0]}{'startreserve'};
+                                if ((!$checkedin) || (ref($consumed_uniq) ne 'ARRAY')) {
+                                    $slotstatus = 'RESERVABLE_LATER';
+                                    $datemsg = $reservable_future->{$reservable_future_order->[0]}{'startreserve'};
+                                } else {
+                                    my ($uniqstart,$uniqend,$useslot);
+                                    if (ref($consumed_uniq) eq 'ARRAY') {
+                                        ($uniqstart,$uniqend)=@{$consumed_uniq};
+                                    }
+                                    foreach my $slot (@{$reservable_future_order}) {
+                                        if ($reservable_future->{$slot}{'uniqueperiod'} =~ /^(\d+),(\d+)$/) {
+                                            my ($new_uniq_start,$new_uniq_end) = ($1,$2);
+                                            next if (!
+                                               ($uniqstart < $new_uniq_start && $uniqend < $new_uniq_start) ||
+                                               ($uniqstart > $new_uniq_end   &&  $uniqend > $new_uniq_end  ));
+                                        }
+                                        $useslot = $slot;
+                                        last;
+                                    }
+                                    if ($useslot) {
+                                        $slotstatus = 'RESERVABLE_LATER';
+                                        $datemsg = $reservable_future->{$useslot}{'startreserve'};
+                                    }
+                                }
                             }
                         }
                     }
@@ -364,7 +456,7 @@ sub check_slot_access {
 # JB, 9/24/2002: Any changes in this function may require a change
 # in lonnavmaps::resource::getDateStatus.
 sub check_access {
-    my ($id) = @_;
+    my ($id,$symb) = @_;
     my $date ='';
     my $status;
     my $datemsg = '';
@@ -394,11 +486,13 @@ sub check_access {
     &Apache::lonxml::debug("checking for part :$id:");
     &Apache::lonxml::debug("time:".time);
 
-    my ($symb)=&Apache::lonnet::whichuser();
+    unless ($symb) {
+        ($symb)=&Apache::lonnet::whichuser();
+    }
     &Apache::lonxml::debug("symb:".$symb);
     #if ($env{'request.state'} ne "construct" && $symb ne '') {
     if ($env{'request.state'} ne "construct") {
-        my $idacc = &Apache::lonnet::EXT("resource.$id.acc");
+        my $idacc = &Apache::lonnet::EXT("resource.$id.acc",$symb);
 	my $allowed=&Apache::loncommon::check_ip_acc($idacc);
 	if (!$allowed && ($Apache::lonhomework::browse ne 'F')) {
 	    $status='INVALID_ACCESS';
@@ -414,12 +508,12 @@ sub check_access {
 	foreach my $temp ("opendate","duedate","answerdate") {
 	    $lastdate = $date;
 	    if ($temp eq 'duedate') {
-		$date = &due_date($id);
+		$date = &due_date($id,$symb);
 	    } else {
-		$date = &Apache::lonnet::EXT("resource.$id.$temp");
+		$date = &Apache::lonnet::EXT("resource.$id.$temp",$symb);
 	    }
 	    
-	    my $thistype = &Apache::lonnet::EXT("resource.$id.$temp.type");
+	    my $thistype = &Apache::lonnet::EXT("resource.$id.$temp.type",$symb);
 	    if ($thistype =~ /^(con_lost|no_such_host)/ ||
 		$date     =~ /^(con_lost|no_such_host)/) {
 		$status='UNAVAILABLE';
@@ -428,10 +522,10 @@ sub check_access {
 	    }
 	    if ($thistype eq 'date_interval') {
 		if ($temp eq 'opendate') {
-		    $date=&Apache::lonnet::EXT("resource.$id.duedate")-$date;
+		    $date=&Apache::lonnet::EXT("resource.$id.duedate",$symb)-$date;
 		}
 		if ($temp eq 'answerdate') {
-		    $date=&Apache::lonnet::EXT("resource.$id.duedate")+$date;
+		    $date=&Apache::lonnet::EXT("resource.$id.duedate",$symb)+$date;
 		}
 	    }
 	    &Apache::lonxml::debug("found :$date: for :$temp:");
@@ -465,7 +559,7 @@ sub check_access {
 	(($Apache::lonhomework::browse eq 'F') && ($status eq 'CLOSED'))) {
 	#check #tries, and if correct.
 	my $tries = $Apache::lonhomework::history{"resource.$id.tries"};
-	my $maxtries = &Apache::lonnet::EXT("resource.$id.maxtries");
+	my $maxtries = &Apache::lonnet::EXT("resource.$id.maxtries",$symb);
 	if ( $tries eq '' ) { $tries = '0'; }
 	if ( $maxtries eq '' && 
 	     $env{'request.state'} ne 'construct') { $maxtries = '2'; } 
@@ -474,7 +568,7 @@ sub check_access {
 	if ( ($Apache::lonhomework::history{"resource.$id.solved"}=~/^correct/)
 	      && (&show_problem_status()) ) {
             if (($Apache::lonhomework::history{"resource.$id.awarded"} >= 1) ||
-                (&Apache::lonnet::EXT("resource.$id.retrypartial") !~/^1|on|yes$/i)) {
+                (&Apache::lonnet::EXT("resource.$id.retrypartial",$symb) !~/^1|on|yes$/i)) {
 	        $status = 'CANNOT_ANSWER';
             }
         } elsif ($Apache::lonhomework::history{"resource.$id.solved"}=~/^excused/) {
@@ -486,14 +580,14 @@ sub check_access {
 	}
     }
     if ($status eq 'CAN_ANSWER' || $status eq 'CANNOT_ANSWER') {
-	my @interval=&Apache::lonnet::EXT("resource.$id.interval");
+	my @interval=&Apache::lonnet::EXT("resource.$id.interval",$symb);
 	&Apache::lonxml::debug("looking for interval @interval");
 	if ($interval[0]) {
-	    my $first_access=&Apache::lonnet::get_first_access($interval[1]);
+	    my $first_access=&Apache::lonnet::get_first_access($interval[1],$symb);
 	    &Apache::lonxml::debug("looking for accesstime $first_access");
 	    if (!$first_access) {
 		$status='NOT_YET_VIEWED';
-		my $due_date = &due_date($id);
+		my $due_date = &due_date($id,$symb);
 		my $seconds_left = $due_date - time;
 		if ($seconds_left > $interval[0] || $due_date eq '') {
 		    $seconds_left = $interval[0];
@@ -767,8 +861,7 @@ sub analyze_header {
        .&Apache::loncommon::head_subbox(
                 &Apache::loncommon::CSTR_pageheader());
     $result .= 
-	&Apache::lonxml::message_location().'
-            <form name="lonhomework" method="post" action="'.
+            '<form name="lonhomework" method="post" action="'.
 	    &HTML::Entities::encode($env{'request.uri'},'<>&"').'">'.
             '<input type="hidden" name="problemmode" value="'.
             $env{'form.problemmode'}.'" />'.
@@ -782,7 +875,8 @@ sub analyze_header {
             <input type="button" name="submitmode" value="'.&mt("View").'" '.
             'onclick="javascript:setmode(this.form,'."'view'".')" />
             <hr />
-            </div>
+            </div>'
+            .&Apache::lonxml::message_location().'
             </form>';
     &Apache::lonxml::add_messages(\$result);
     $request->print($result);
@@ -1010,27 +1104,88 @@ sub editxmlmode {
             '<form '.&Apache::edit::form_change_detection().' name="lonhomework" method="post" action="'.
 	    &HTML::Entities::encode($env{'request.uri'},'<>&"').'">'.
 	    &Apache::structuretags::remember_problem_state().'
-            <div class="LC_edit_problem_editxml_header">
-              <table class="LC_edit_problem_header_title"><tr><td>
-               <h2>'.&mt('Problem Editing').' '.&Apache::loncommon::help_open_topic('Problem_Editor_XML_Index').'</h2>
-                </td><td align="right">
-                  '.&Apache::loncommon::helpLatexCheatsheet('Problem_LON-CAPA_Functions','Script Functions').'
-                </td></tr>
-              </table>';
+            <div class="LC_edit_problem_header">
+              <div class="LC_edit_problem_header_title">'.
+                &mt('Problem Editing').' '.&Apache::loncommon::help_open_topic('Problem_Editor_XML_Index').
+                '</div><div class="LC_edit_actionbar" id="actionbar">';
 
-         $result.='<input type="hidden" name="problemmode" value="saveedit" />'.
+    $result.='<input type="hidden" name="problemmode" value="saveedit" />'.
                   &Apache::structuretags::problem_edit_buttons('editxml');
-         
-         $result.='<hr style="clear:both;" />'.&Apache::lonxml::message_location().'</div>'.  
-                  '<textarea '.&Apache::edit::element_change_detection().
-	              ' rows="'.$rows.'" cols="'.$cols.'" style="width:100%" '.
-		      ' name="editxmltext" id="LC_editxmltext">'.
-		      &HTML::Entities::encode($problem,'<>&"').'</textarea>
-            <div id="LC_aftertextarea">
-            </div>
-            </form>'.&Apache::loncommon::end_page();
-	&Apache::lonxml::add_messages(\$result);
-	$request->print($result);
+    $result.='<div>';
+
+    $result .= '<ol class="LC_primary_menu" style="display:inline-block;font-size:90%;vertical-align:middle;">';
+
+    unless ($env{'environment.nocodemirror'}) {
+        # dropdown menus
+        $result .= Apache::lonmenu::create_submenu("#", "",
+            &mt("Problem Templates"), template_dropdown_datastructure());
+
+        $result .= Apache::lonmenu::create_submenu("#", "",
+            &mt("Response Types"), responseblock_dropdown_datastructure());
+
+        $result .= Apache::lonmenu::create_submenu("#", "",
+            &mt("Conditional Blocks"), conditional_scripting_datastructure());
+
+        $result .= Apache::lonmenu::create_submenu("#", "",
+            &mt("Miscellaneous"), misc_datastructure());
+    }
+
+    $result .= Apache::lonmenu::create_submenu("#", "",
+        &mt("Help") . ' <img src="/adm/help/help.png" alt="' . &mt("Help") .
+        '" style="vertical-align:text-bottom; height: auto; margin:0; "/>',
+        helpmenu_datastructure(),"");
+
+    $result.="</ol></div>";
+
+    $result .= '</div></div>' .
+        &Apache::lonxml::message_location() .
+        &Apache::loncommon::xmleditor_js() .
+        '<textarea ' . &Apache::edit::element_change_detection() .
+        ' rows="'.$rows.'" cols="'.$cols.'" style="width:100%" ' .
+        ' name="editxmltext" id="LC_editxmltext">' .
+        &HTML::Entities::encode($problem,'<>&"') .
+        '</textarea> <div id="LC_aftertextarea"> </div> </form>';
+
+    my $resource = $env{'request.ambiguous'};
+    unless($env{'environment.nocodemirror'}){
+        $result .= '<link rel="stylesheet" href="/adm/codemirror/codemirror-combined-xml.css">
+        <script src="/adm/codemirror/codemirror-compressed-xml.js"></script>
+        <script>
+            CodeMirror.defineMode("mixedmode", function(config) {
+                return CodeMirror.multiplexingMode(
+                    CodeMirror.getMode(config, "xml"),
+                    {
+                        open: "\<script type=\"loncapa/perl\"\>", close: "\</script\>",
+                        mode: CodeMirror.getMode(config, "perl"),
+                        delimStyle: "tag",
+                    }
+              );
+            });
+            var cm = CodeMirror.fromTextArea(document.getElementById("LC_editxmltext"),
+            {
+                mode: "mixedmode",
+                lineWrapping: true,
+                lineNumbers: true,
+                tabSize: 4,
+                indentUnit: 4,
+
+                autoCloseTags: true,
+                autoCloseBrackets: true,
+                height: "auto",
+                styleActiveLine: true,
+
+                extraKeys: {
+                    "Tab": "indentMore",
+                    "Shift-Tab": "indentLess",
+                }
+            });
+            restoreScrollPosition("'.$resource.'");
+        </script>';
+    }
+
+    $result .= &Apache::loncommon::end_page();
+    &Apache::lonxml::add_messages(\$result);
+    $request->print($result);
     }
     return '';
 }
@@ -1117,21 +1272,35 @@ sub finished_parsing {
     undef($Apache::lonhomework::parsing_a_task);
 }
 
+
+# function extracted from get_template_html
+# returns "key" -> list
+# key: path of template
+# value 1: title
+# value 2: category
+# value 3: name of help topic ???
 sub get_template_list {
     my ($extension) = @_;
+
+    my @files = glob($Apache::lonnet::perlvar{'lonIncludes'}.
+		     '/templates/*.'.$extension);
+    @files = map {[$_,&mt(&Apache::lonnet::metadata($_, 'title')),
+                      (&Apache::lonnet::metadata($_, 'category')?&mt(&Apache::lonnet::metadata($_, 'category')):&mt('Miscellaneous')),
+                     &mt(&Apache::lonnet::metadata($_, 'help'))]} (@files);
+    @files = sort {$a->[2].$a->[1] cmp $b->[2].$b->[1]} (@files);
+    return @files;
+}
+
+sub get_template_html {
+    my ($extension) = @_;
     my $result;
     my @allnames;
     &Apache::lonxml::debug("Looking for :$extension:");
     my $glob_extension  = $extension;
     if ($extension eq 'survey' || $extension eq 'exam') {
-	$glob_extension = 'problem';
+        $glob_extension = 'problem';
     }
-    my @files = glob($Apache::lonnet::perlvar{'lonIncludes'}.
-		     '/templates/*.'.$glob_extension);
-    @files = map {[$_,&mt(&Apache::lonnet::metadata($_, 'title')),
-                      (&Apache::lonnet::metadata($_, 'category')?&mt(&Apache::lonnet::metadata($_, 'category')):&mt('Miscellaneous')),
-                      &Apache::lonnet::metadata($_, 'help')]} (@files);
-    @files = sort {$a->[2].$a->[1] cmp $b->[2].$b->[1]} (@files);
+    my @files = &get_template_list($extension);
     my ($midpoint,$seconddiv,$numfiles);
     my @noexamplelink = ('blank.problem','blank.library','script.library');
     $numfiles = 0;
@@ -1193,17 +1362,44 @@ sub get_template_list {
 sub newproblem {
     my ($request) = @_;
 
+    if ($env{'form.mode'} eq 'blank'){
+        my $dest = &Apache::lonnet::filelocation("",$request->uri);
+        my $templatefilename =
+            $request->dir_config('lonIncludes').'/templates/blank.problem';
+        &File::Copy::copy($templatefilename,$dest);
+        &renderpage($request,$dest);
+        return;
+    }
+    my $errormsg;
     if ($env{'form.template'}) {
-	my $file = $env{'form.template'};
-	my $dest = &Apache::lonnet::filelocation("",$request->uri);
-	&File::Copy::copy($file,$dest);
-	&renderpage($request,$dest);
-	return;
+        my $file;
+        my ($extension) = ($env{'form.template'} =~ /\.(\w+)$/);
+        if ($extension) {
+            my @files = &get_template_list($extension);
+            foreach my $poss (@files) {
+                if (ref($poss) eq 'ARRAY') {
+                    if ($env{'form.template'} eq $poss->[0]) {
+                        $file = $env{'form.template'};
+                        last;
+                    }
+                }
+            }
+            if ($file) {
+                my $dest = &Apache::lonnet::filelocation("",$request->uri);
+                &File::Copy::copy($file,$dest);
+                &renderpage($request,$dest);
+                return;
+            } else {
+                $errormsg = '<p class="LC_error">'.&mt('Invalid template file.').'</p>';
+            }
+        } else {
+            $errormsg = '<p class="LC_error">'.&mt('Invalid template file; template needs to be a .problem, .library, or .task file.').'</p>';
+        }
     }
 
     my ($extension) = ($request->uri =~ m/\.(\w+)$/);
     &Apache::lonxml::debug("Looking for :$extension:");
-    my $templatelist=&get_template_list($extension);
+    my $templatelist=&get_template_html($extension);
     if ($env{'form.newfile'} && !$templatelist) {
 	# no templates found
 	my $templatefilename =
@@ -1215,7 +1411,6 @@ sub newproblem {
     } else {
 	my $url=&HTML::Entities::encode($request->uri,'<>&"');
 	my $dest = &Apache::lonnet::filelocation("",$request->uri);
-	my $errormsg;
 	my $instructions;
         my $brcrum = [{'href' => &Apache::loncommon::authorspace($request->uri),
                        'text' => 'Authoring Space'},
@@ -1315,6 +1510,8 @@ sub handler {
 		&renderpage($request,$file);
 	    }
 	} else {
+            &Apache::loncommon::get_unprocessed_cgi($ENV{'QUERY_STRING'},
+                                                    ['mode']);
 	    # requested file doesn't exist in contruction space
 	    &newproblem($request);
 	}
@@ -1332,5 +1529,179 @@ sub handler {
 
 }
 
+sub template_dropdown_datastructure {
+    # gathering the all templates and their path, title, category and help topic
+    my @templates = get_template_list('problem');
+    # template category => title
+    my %tmplthash = ();
+    # template title => path
+    my %tmpltcontent = ();
+
+    foreach my $template (@templates){
+        # put in hash if the template is not empty
+        unless ($template->[1] eq ''){
+            push(@{$tmplthash{$template->[2]}}, $template->[1]);
+            push(@{$tmpltcontent{$template->[1]}},$template->[0]);
+        }
+    }
+
+        my $catList = [];
+    foreach my $cat (sort keys %tmplthash) {
+                my $catItems = [];
+        foreach my $title (sort @{$tmplthash{$cat}}) {
+            my $path = $tmpltcontent{$title}->[0];
+            my $code;
+            open(FH, "<$path");
+            while(<FH>){
+                $code.= $_ unless $_ =~ /(<problem>)|(<\/problem>)/;
+            }
+            close(FH);
+
+                        if ($code ne '') {
+                my $href = 'javascript:insertText(\'' . &convert_for_js(&HTML::Entities::encode($code,'<>&"')) . '\')';
+                                my $currItem = [$href, $title, undef];
+                                push @{$catItems}, $currItem;
+                        }
+        }
+                push @{$catList}, [$catItems, $cat, undef];
+    }
+
+    return $catList;
+}
+
+sub responseblock_dropdown_datastructure {
+
+    my $mathCat = [
+                    [
+                        ["javascript:insertText(\'" . &convert_for_js(&HTML::Entities::encode(&Apache::edit::insert_formularesponse())) . "\')", &mt("Formula Response"), undef],
+                        ["javascript:insertText(\'" . &convert_for_js(&HTML::Entities::encode(&Apache::edit::insert_functionplotresponse())) . "\')", &mt("Function Plot Response"), undef],
+                        ["javascript:insertText(\'" . &convert_for_js(&HTML::Entities::encode(&Apache::edit::insert_mathresponse())) . "\')", &mt("Math Response"), undef],
+                        ["javascript:insertText(\'" . &convert_for_js(&HTML::Entities::encode(&Apache::edit::insert_numericalresponse())) . "\')", &mt("Numerical Response"), undef]
+                    ],
+                    &mt("Math"),
+                    undef
+        ];
+
+    my $miscCat = [
+                    [
+            ["javascript:insertText(\'" . &convert_for_js(&HTML::Entities::encode(&Apache::edit::insert_imageresponse())) . "\')", &mt("Click on Image"), undef],
+            ["javascript:insertText(\'" . &convert_for_js(&HTML::Entities::encode(&Apache::edit::insert_customresponse())) . "\')", &mt("Custom Response"), undef],
+            ["javascript:insertText(\'" . &convert_for_js(&HTML::Entities::encode(&Apache::edit::insert_externalresponse())) . "\')", &mt("External Response"), undef],
+            ["javascript:insertText(\'" . &convert_for_js(&HTML::Entities::encode(&Apache::edit::insert_matchresponse())) . "\')", &mt("Match Two Lists"), undef],
+            ["javascript:insertText(\'" . &convert_for_js(&HTML::Entities::encode(&Apache::edit::insert_radiobuttonresponse())) . "\')", &mt("One out of N statements"), undef],
+            ["javascript:insertText(\'" . &convert_for_js(&HTML::Entities::encode(&Apache::edit::insert_optionresponse())) . "\')", &mt("Select from Options"), undef],
+                        ["javascript:insertText(\'" . &convert_for_js(&HTML::Entities::encode(&Apache::edit::insert_rankresponse())) . "\')", &mt("Rank Values"), undef]
+                ],
+                &mt("Miscellaneous"),
+                undef
+        ];
+
+    my $chemCat = [
+                    [
+                        ["javascript:insertText(\'" . &convert_for_js(&HTML::Entities::encode(&Apache::edit::insert_reactionresponse())) . "\')", &mt("Chemical Reaction"), undef],
+                        ["javascript:insertText(\'" . &convert_for_js(&HTML::Entities::encode(&Apache::edit::insert_organicresponse())) . "\')", &mt("Organic Chemical Structure"), undef]
+                     ],
+                     &mt("Chemistry"),
+                     undef
+                   ];
+
+    my $textCat = [
+                    [
+                      ["javascript:insertText(\'" . &convert_for_js(&HTML::Entities::encode(&Apache::edit::insert_stringresponse())) . "\')", &mt("String Response"), undef],
+                      ["javascript:insertText(\'" . &convert_for_js(&HTML::Entities::encode(&Apache::edit::insert_essayresponse())) . "\')", &mt("Essay"), undef]
+                     ],
+                     &mt("Text"),
+                     undef
+                   ];
+
+    return [$mathCat, $miscCat, $chemCat, $textCat];
+}
+
+
+sub conditional_scripting_datastructure {
+# TODO: corresponding routines should be used for the javascript:insertText parts
+# instead of the placeholder routine default_xml_tag with the tags
+# e.g. &default_xml_tag("postanswerdate") should be replaced with a routine which
+# returns the corresponding content for this case
+
+#TODO translated is currently temporarily here, another solution should be found where the
+# needed string can be retrieved
+
+    my $translatedTag = '
+<translated>
+    <lang which="en"></lang>
+    <lang which="default"></lang>
+</translated>';
+    return [
+             ["javascript:insertText(\'" . &convert_for_js(&HTML::Entities::encode($translatedTag)) . "\')", &mt("Translated Block"), undef],
+             ["javascript:insertText(\'" . &convert_for_js(&HTML::Entities::encode(&default_xml_tag("block"))) . "\')", &mt("Conditional Block"), undef],
+             ["javascript:insertText(\'" . &convert_for_js(&HTML::Entities::encode(&default_xml_tag("postanswerdate"))) . "\')", &mt("After Answer Date Block"), undef],
+             ["javascript:insertText(\'" . &convert_for_js(&HTML::Entities::encode(&default_xml_tag("preduedate"))) . "\')", &mt("Before Due Date Block"), undef],
+             ["javascript:insertText(\'" . &convert_for_js(&HTML::Entities::encode(&default_xml_tag("solved"))) . "\')", &mt("Block For After Solved"), undef],
+             ["javascript:insertText(\'" . &convert_for_js(&HTML::Entities::encode(&default_xml_tag("notsolved"))) . "\')", &mt("Block For When Not Solved"), undef]
+        ];
+}
+
+sub misc_datastructure {
+    return [
+        ["javascript:insertText(\'" . &convert_for_js(&HTML::Entities::encode(&Apache::edit::insert_img())) . "\')", &mt("Image"), undef],
+        ["javascript:insertText(\'" . &convert_for_js(&HTML::Entities::encode(&Apache::lonplot::insert_gnuplot())) . "\')", &mt("GNU Plot"), undef],
+        ["javascript:insertText(\'" . &convert_for_js(&HTML::Entities::encode(&Apache::edit::insert_organicstructure())) . "\')", &mt("Organic Structure"), undef],
+        ["javascript:insertText(\'" . &convert_for_js(&HTML::Entities::encode(&Apache::edit::insert_script())) . "\')", &mt("Script Block"), undef],
+        ["javascript:insertText(\'" . &convert_for_js(&HTML::Entities::encode(&default_xml_tag("allow"))) . "\')", &mt("File Dependencies"), undef],
+        ["javascript:insertText(\'" . &convert_for_js(&HTML::Entities::encode(&default_xml_tag("import"))) . "\')", &mt("Import a File"), undef],
+        ["javascript:insertText(\'" . &convert_for_js(&HTML::Entities::encode(&Apache::londefdef::insert_meta())) . "\')", &mt("Custom Metadata"), undef],
+        ["javascript:insertText(\'" . &convert_for_js(&HTML::Entities::encode(&default_xml_tag("part"))) . "\')", &mt("Problem Part"), undef]
+    ];
+}
+
+# helper routine for the datastructure building subroutines
+sub default_xml_tag {
+    my ($tag) = @_;
+    return "\n<$tag></$tag>";
+}
+
+sub helpmenu_datastructure {
+
+    # filename, title, width, height
+    my $helpers = [
+                    ['Problem_LON-CAPA_Function.hlp', &mt('Script Functions'), 800, 600],
+                    ['Greek_Symbols.hlp', &mt('Greek Symbols'), 500, 600],
+                    ['Other_Symbols.hlp', &mt('Other Symbols'), 500, 600],
+                    ['Authoring_Output_Tags.hlp', &mt('Output Tags'), 800, 600],
+                    ['Authoring_Multilingual_Problems.hlp', &mt('Languages'), 800, 600],
+                   ];
+
+    my $help_structure = [];
+
+    foreach my $count (0..(scalar(@{$helpers})-1)) {
+        my $filename = $helpers->[$count]->[0];
+        my $title = $helpers->[$count]->[1];
+        my $width = $helpers->[$count]->[2];
+        my $height = $helpers->[$count]->[3];
+        if ($width eq '') {
+            $width = 500;
+        }
+        if ($height eq '') {
+            $height = 600;
+        }
+        my $href = &HTML::Entities::encode("javascript:openMyModal('/adm/help/$filename',$width,$height,'yes');");
+        push @{$help_structure}, [$href, $title, undef];
+    }
+
+    return $help_structure;
+}
+
+# we need substitution to not break javascript code
+sub convert_for_js {
+    my $return = shift;
+    $return =~ s|script|ESCAPEDSCRIPT|g;
+    $return =~ s|\\|\\\\|g;
+    $return =~ s|\n|\\r\\n|g;
+    $return =~ s|'|\\'|g;
+    $return =~ s|&#39;|\\&#39;|g;
+    return $return;
+}
+
 1;
 __END__
