@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Full matching style response
 #
-# $Id: matchresponse.pm,v 1.91 2014/05/05 17:40:54 bisitz Exp $
+# $Id: matchresponse.pm,v 1.92 2015/01/19 15:35:53 goltermann Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -55,7 +55,7 @@ sub start_matchresponse {
 	$result=&Apache::response::meta_package_write('matchresponse');
     } elsif ($target eq 'edit' ) {
 	$result.=&Apache::edit::start_table($token).
-	    '<tr><td>'.&Apache::lonxml::description($token).'</td>'
+	    '<tr><td>'.&Apache::loncommon::insert_folding_button().&Apache::lonxml::description($token).'</td>'
            .'<td><span class="LC_nobreak">'.&mt('Delete?').' '
 	   .&Apache::edit::deletelist($target,$token)
            .'</span></td>'
@@ -319,7 +319,8 @@ sub start_foilgroup {
     &Apache::response::pushrandomnumber(undef,$target);
     if ($target eq 'edit') {
 	$result.=&Apache::edit::start_table($token)
-	    .'<tr><td>'.&mt('Collection Of Foils').'</td>'
+	    .'<tr><td>'.&Apache::loncommon::insert_folding_button()
+            .&mt('Collection Of Foils').'</td>'
             .'<td><span class="LC_nobreak">'.&mt('Delete?')
 	    .&Apache::edit::deletelist($target,$token)
 	    .'</span></td>'
