@@ -1,7 +1,7 @@
 # LearningOnline Network with CAPA
 # option list style responses
 #
-# $Id: optionresponse.pm,v 1.195.2.1 2015/04/21 23:36:43 raeburn Exp $
+# $Id: optionresponse.pm,v 1.195.2.2 2016/09/14 18:30:06 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -51,7 +51,8 @@ sub start_optionresponse {
   undef(%Apache::response::foilnames);
   if ($target eq 'edit') {
     $result.=&Apache::edit::start_table($token)
-       .'<tr><td><span class="LC_nobreak">'.&mt('Multiple Option Response Question').'</span> '
+       .'<tr><td><span class="LC_nobreak">'.&Apache::loncommon::insert_folding_button().' '
+       .&mt('Multiple Option Response Question').'</span> '
        .&Apache::loncommon::help_open_topic('Option_Response_Problems')."</td>"
        .'<td><span class="LC_nobreak">'.&mt('Delete?').' '
        .&Apache::edit::deletelist($target,$token)
@@ -127,8 +128,8 @@ sub start_foilgroup {
         maxcheck => 'Enter maximum number students may check (e.g., 3)',
         mincheck => 'Enter minimum number students need to check (e.g., 1)',
     );
-    $result.= (<<ENDTABLE);
-      <tr><td>$lt{'sel'}</td>
+    $result.= sprintf(<<ENDTABLE, &Apache::loncommon::insert_folding_button());
+      <tr><td>%s $lt{'sel'}</td>
         <td>
 	  $lt{'add'} <input type="text" name="$Apache::lonxml::curdepth.options" />
         </td>
