@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA 
 # tags that create controlled output
 #
-# $Id: outputtags.pm,v 1.57 2010/02/24 12:14:45 foxr Exp $
+# $Id: outputtags.pm,v 1.58 2016/08/09 23:43:42 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -78,8 +78,8 @@ sub substitute_simple_tags_latex {
 
     # restore the <>'s:
 
-    $string =~ s/\\ensuremath{<}/</g;
-    $string =~ s/\\ensuremath{>}/>/g;
+    $string =~ s/\\ensuremath\{<}/</g;
+    $string =~ s/\\ensuremath\{>}/>/g;
 
 
     # Substitute the tags:
