@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 # 
-# $Id: imsimport.pm,v 1.46 2014/12/11 01:07:38 raeburn Exp $
+# $Id: imsimport.pm,v 1.47 2015/06/09 21:22:51 damieng Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -57,22 +57,26 @@ sub jscript_one {
     my $end_page = 
 	&Apache::loncommon::end_page({'js_ready' => 1,});
 
-    my %lt = &Apache::lonlocal::texthash( 
+    my %js_lt = &Apache::lonlocal::texthash( 
                ddir => 'You must choose a destination directory for the import',
                cmss => 'You must choose the Course Management System from which the IMS package was exported',
+             );
+    my %html_lt = &Apache::lonlocal::texthash( 
                loca => 'Location:',
                newd => 'New Directory',
                nndi => 'Enter the name of the new directory where you will store the contents of your IMS package.',
                go => 'Go', 
              );
+    &js_escape(\%js_lt);
+    &html_escape(\%html_lt);
     return <<"END_OF_ONE";
 function verify() {
  if ((document.forms.$formname.newdir.value == '')  || (!document.forms.$formname.newdir.value)) {
-   alert('$lt{'ddir'}')
+   alert('$js_lt{'ddir'}')
    return false
  }
  if (document.forms.$formname.source.selectedIndex == 0) {
-   alert('$lt{'cmss'}');
+   alert('$js_lt{'cmss'}');
    return false
  }
  return true
@@ -92,15 +96,15 @@ function createWin() {
   newWindow.document.write("\\n<img border='0' src='/adm/lonInterFace/author.jpg' alt='[Author Header]' />\\n")
   newWindow.document.write("<table border='0' cellspacing='0' cellpadding='0' width='600'>\\n")
   newWindow.document.write("<tr><td width='2'>&nbsp;</td><td width='3'>&nbsp;</td>\\n")
-  newWindow.document.write("<td><h3>$lt{'loca'} <tt>$fullpath</tt></h3><h3>$lt{'newd'}</h3></td></tr>\\n")
+  newWindow.document.write("<td><h3>$html_lt{'loca'} <tt>$fullpath</tt></h3><h3>$html_lt{'newd'}</h3></td></tr>\\n")
   newWindow.document.write("<tr><td width='2'>&nbsp;</td><td width='3'>&nbsp;</td>\\n")
   newWindow.document.write("<td><form name='fileaction' action='/adm/cfile' method='post'>\\n")
-  newWindow.document.write("$lt{'nndi'}<br /><br />")
+  newWindow.document.write("$html_lt{'nndi'}<br /><br />")
   newWindow.document.write("<input type='hidden' name='filename' value='$fullpath' />")
   newWindow.document.write("<input type='hidden' name='action' value='newdir' />")
   newWindow.document.write("<input type='hidden' name='callingmode' value='imsimport' />")
   newWindow.document.write("$fullpath<input type='text' name='newfilename' value='' />")
-  newWindow.document.write("<input type='button' value='$lt{'go'}' onclick='document.fileaction.submit();' />")
+  newWindow.document.write("<input type='button' value='$html_lt{'go'}' onclick='document.fileaction.submit();' />")
   newWindow.document.write("</td></tr>\\n")
   newWindow.document.write("</table>")
   newWindow.document.write('$end_page')
@@ -133,7 +137,7 @@ sub jscript_two {
     $course_list = '"'.join('","',@crslist).'"';
     $$numcrs = @crslist;
 
-    my %lt = &Apache::lonlocal::texthash(
+    my %js_lt = &Apache::lonlocal::texthash(
                   sel    => 'Please select',
                   impto  => 'Import topics only',
                   imptpa => 'Import topics + posts (with author)',
@@ -147,6 +151,7 @@ sub jscript_two {
                   errte  => 'You must select a target course when importing enrollment information.',
                   errcc  => 'You must check at least one Content Type.',
        );
+    &js_escape(\%js_lt);
     return <<"END_OF_TWO";
 
 function checkCourse() {
@@ -195,7 +200,7 @@ function setCourse(step2Form,call) {
     step2Form.targetcourse.length = 0
     if (call == 'add') {
         step2Form.targetcourse.length = 0
-        step2Form.targetcourse.options[0] = new Option("$lt{'sel'}","0",true,true)
+        step2Form.targetcourse.options[0] = new Option("$js_lt{'sel'}","0",true,true)
         for (var i=0; i<courseID_array.length; i++) {
             step2Form.targetcourse.options[i+1] = new Option(courseTitle_array[i],courseID_array[i],false,false)
         }
@@ -215,22 +220,22 @@ function setOptions(caller,itemnum) {
   opForm.elements[menu].length = 0
   if (opForm.elements[itemnum*2].checked == true) {
     if (caller == "board") {
-      opForm.elements[menu].options[0] = new Option("$lt{'sel'}","-1",true,true)
-      opForm.elements[menu].options[1] = new Option("$lt{'impto'}","topics",true,true)
-      opForm.elements[menu].options[2] = new Option("$lt{'imptpa'}","allpost",true,true)
-      opForm.elements[menu].options[3] = new Option("$lt{'imptpn'}","allanon",true,true)
+      opForm.elements[menu].options[0] = new Option("$js_lt{'sel'}","-1",true,true)
+      opForm.elements[menu].options[1] = new Option("$js_lt{'impto'}","topics",true,true)
+      opForm.elements[menu].options[2] = new Option("$js_lt{'imptpa'}","allpost",true,true)
+      opForm.elements[menu].options[3] = new Option("$js_lt{'imptpn'}","allanon",true,true)
     }
     else { 
       if (caller == "users") {
         opForm.elements[menu].length = 0
-        opForm.elements[menu].options[0] = new Option("$lt{'sel'}","-1",true,true)
-        opForm.elements[menu].options[1] = new Option("$lt{'enrst'}","students",true,true)
-        opForm.elements[menu].options[2] = new Option("$lt{'enrall'}","all",true,true)
+        opForm.elements[menu].options[0] = new Option("$js_lt{'sel'}","-1",true,true)
+        opForm.elements[menu].options[1] = new Option("$js_lt{'enrst'}","students",true,true)
+        opForm.elements[menu].options[2] = new Option("$js_lt{'enrall'}","all",true,true)
       }
     }
   }
   else {
-    opForm.elements[menu].options[0] = new Option("$lt{'notreq'}","0",true,true)
+    opForm.elements[menu].options[0] = new Option("$js_lt{'notreq'}","0",true,true)
   }
   opForm.elements[menu].selectedIndex = 0
   if (numCrs > 0) {
@@ -248,7 +253,7 @@ function verify(caller) {
       totcheck ++
       if (opForm.elements[2*i].name == "board") { 
         if (opForm.elements[2*i+1].selectedIndex == 0) {     
-          alert("$lt{'errao'}")
+          alert("$js_lt{'errao'}")
           return false
         }
         if (numCrs == 0) {
@@ -257,14 +262,14 @@ function verify(caller) {
         }
         else {
           if (opForm.targetcourse.selectedIndex == 0) {
-            alert("$lt{'errtd'}")
+            alert("$js_lt{'errtd'}")
             return false
           }
         }
       }
       if (opForm.elements[2*i].name == "users") {
         if (opForm.elements[2*i+1].selectedIndex == 0) {     
-          alert("$lt{'errap'}")
+          alert("$js_lt{'errap'}")
           return false
         }
         if (numCrs == 0) {
@@ -273,7 +278,7 @@ function verify(caller) {
         }
         else {
           if (opForm.targetcourse.selectedIndex == 0) {
-            alert("$lt{'errte'}")
+            alert("$js_lt{'errte'}")
             return false
           }
         }
@@ -281,7 +286,7 @@ function verify(caller) {
     }
   }
   if (totcheck == 0) {
-    alert("$lt{'errcc'}");
+    alert("$js_lt{'errcc'}");
     return false
   }
   return true
