@@ -4,7 +4,7 @@
 # kerberos, or SSO) or an e-mail address. Requests to use an e-mail address as
 # username may be processed automatically, or may be queued for approval.
 #
-# $Id: createaccount.pm,v 1.69 2015/01/09 15:41:49 raeburn Exp $
+# $Id: createaccount.pm,v 1.72 2016/02/19 20:28:46 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -319,7 +319,7 @@ sub print_footer {
         $r->print('<form name="backupcrumbs" method="post" action="">'.
                   &Apache::lonhtmlcommon::echo_form_input(['backto','logtoken',
                       'token','serverid','uname','upass','phase','create_with_email',
-                      'code','crypt','cfirstname','clastname',
+                      'code','crypt','cfirstname','clastname','g-recaptcha-response',
                       'recaptcha_challenge_field','recaptcha_response_field',
                       'cmiddlename','cgeneration','cpermanentemail','cid']).
                   '</form>');
@@ -366,7 +366,7 @@ sub selfenroll_crumbs {
 }
 
 sub javascript_setforms {
-    my ($now,$emailusername,$captcha,$usertype) =  @_;
+    my ($now,$emailusername,$captcha,$usertype,$recaptchaversion) =  @_;
     my ($setuserinfo,@required,$requiredchk);
     if (ref($emailusername) eq 'HASH') {
         if (ref($emailusername->{$usertype}) eq 'HASH') {  
@@ -382,13 +382,16 @@ sub javascript_setforms {
             $setuserinfo .= '                    server.elements.code.value=client.elements.code.value;'."\n".
                             '                    server.elements.crypt.value=client.elements.crypt.value;'."\n";
         } elsif ($captcha eq 'recaptcha') {
-            $setuserinfo .= 
+            if ($recaptchaversion ne '2') {
+                $setuserinfo .=
                 '                    server.elements.recaptcha_challenge_field.value=client.elements.recaptcha_challenge_field.value;'."\n".
                 '                    server.elements.recaptcha_response_field.value=client.elements.recaptcha_response_field.value;'."\n";
+            }
         }
     }
     if (@required) {
         my $missprompt = &mt('One or more required fields are currently blank.');
+        &js_escape(\$missprompt);
         my $reqstr = join("','",@required);
         $requiredchk = <<"ENDCHK";
                 var requiredfields = new Array('$reqstr');
@@ -430,7 +433,7 @@ $requiredchk
                 initkeys();
 
                 server.elements.upass.value
-                    = crypted(client.elements.upass$now.value);
+                    = getCrypted(client.elements.upass$now.value);
 
                 client.elements.uname.value='';
                 client.elements.upass$now.value='';
@@ -443,17 +446,23 @@ $setuserinfo
         }
         return false;
     }
+
 // ]]>
 </script>
 ENDSCRIPT
+    if (($captcha eq 'recaptcha') && ($recaptchaversion eq '2')) {
+        $js .= "\n".'<script src="https://www.google.com/recaptcha/api.js"></script>'."\n";
+    }
     return $js;
 }
 
 sub javascript_checkpass {
     my ($now,$context) = @_;
     my $nopass = &mt('You must enter a password.');
-    my $mismatchpass = &mt('The passwords you entered did not match.').'\\n'.
+    my $mismatchpass = &mt('The passwords you entered did not match.')."\n".
                        &mt('Please try again.'); 
+    &js_escape(\$nopass);
+    &js_escape(\$mismatchpass);
     my $js = <<"ENDSCRIPT";
 <script type="text/javascript">
 // <![CDATA[
@@ -487,18 +496,19 @@ ENDSCRIPT
 }
 
 sub javascript_validmail {
-    my %lt = &Apache::lonlocal::texthash (
+    my %js_lt = &Apache::lonlocal::texthash (
                email => 'The e-mail address you entered',
                notv  => 'is not a valid e-mail address',
     );
     my $output =  "\n".'<script type="text/javascript">'."\n".
                   '// <![CDATA['."\n".
                   &Apache::lonhtmlcommon::javascript_valid_email()."\n";
+    &js_escape(\%js_lt);
     $output .= <<"ENDSCRIPT";
 function validate_email(client) {
     field = client.uname;
     if (validmail(field) == false) {
-        alert("$lt{'email'}: "+field.value+" $lt{'notv'}.");
+        alert("$js_lt{'email'}: "+field.value+" $js_lt{'notv'}.");
         return false;
     }
     return true;
@@ -539,7 +549,8 @@ sub print_username_form {
         }
         if (grep(/^email$/,@{$cancreate})) {
             $output .= '<div class="LC_left_float"><h3>'.&mt('Create account with an e-mail address as your username').'</h3>';
-            my ($captchaform,$error,$captcha) = &Apache::loncommon::captcha_display('usercreation',$lonhost);
+            my ($captchaform,$error,$captcha,$recaptchaversion) = 
+                &Apache::loncommon::captcha_display('usercreation',$lonhost);
             if ($error) {
                 my $helpdesk = '/adm/helpdesk?origurl=%2fadm%2fcreateaccount';
                 if ($courseid ne '') {
@@ -568,7 +579,8 @@ sub print_username_form {
                                $lt{'yopw'}.'<br />';
                 }
                 $output .= &print_dataentry_form($r,$domain,$lonhost,$include,$now,$captchaform,
-                                                 $courseid,$emailusername,$captcha,$usertype);
+                                                 $courseid,$emailusername,$captcha,$usertype,
+                                                 $recaptchaversion);
             }
             $output .= '</div>';
         }
@@ -881,15 +893,15 @@ sub start_session {
 #
 sub print_dataentry_form {
     my ($r,$domain,$lonhost,$include,$now,$captchaform,$courseid,$emailusername,$captcha,
-        $usertype) = @_;
+        $usertype,$recaptchaversion) = @_;
     my ($error,$output);
     if (open(my $jsh,"<$include/londes.js")) {
         while(my $line = <$jsh>) {
             $r->print($line);
         }
         close($jsh);
-        $output = &javascript_setforms($now,$emailusername,$captcha,$usertype)."\n".
-                  &javascript_checkpass($now,'email');
+        $output = &javascript_setforms($now,$emailusername,$captcha,$usertype,$recaptchaversion).
+                  "\n".&javascript_checkpass($now,'email');
         my ($lkey,$ukey) = &Apache::loncommon::des_keys();
         my ($lextkey,$uextkey) = &getkeys($lkey,$ukey);
         my $logtoken=Apache::lonnet::reply('tmpput:'.$ukey.$lkey.'&createaccount:createaccount',
@@ -913,10 +925,15 @@ sub print_dataentry_form {
    <input type="hidden" name="code" value="" />
 ';
         } elsif ($captcha eq 'recaptcha') {
-            $output .= '
+            if ($recaptchaversion eq '2') {
+                $output .= "$captchaform\n";
+                undef($captchaform);
+            } else {
+                $output .= '
    <input type="hidden" name="recaptcha_challenge_field" value="" />
    <input type="hidden" name="recaptcha_response_field" value="" />
 ';
+            }
         }
         $output .= <<"ENDSERVERFORM";
    <input type="hidden" name="logtoken" value="$logtoken" />
