@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # entity -> tex.
 #
-# $Id: entities.pm,v 1.20 2014/06/19 19:18:17 raeburn Exp $
+# $Id: entities.pm,v 1.22 2014/10/14 18:30:23 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -87,7 +87,7 @@ use strict;
 
     The general punctuation set
 
-=item (8472-8501)
+=item (8462-8501)
 
     Letter like symbols
 
@@ -637,7 +637,11 @@ my %entities = (
     'euro'   => '\texteuro',
 
     # Letter like symbols
-    
+ 
+    8462     => '\ensuremath{h}',
+    'planckh' => '\ensuremath{h}',
+    8463     => '\ensuremath{\hbar}',
+    'hbar'   => '\ensuremath{\hbar}',   
     8472     => '\ensuremath{\wp}',
     'weierp' => '\ensuremath{\wp}',
     8465     => '\ensuremath{\Im}',
@@ -789,7 +793,10 @@ my %entities = (
     'cong'   => '\ensuremath{\cong}',
     8773     => '\ensuremath{\cong}',
     8775     => '\ensuremath{\ncong}',
+    8776     => '\ensuremath{\approx}',
+    'approx' => '\ensuremath{\approx}', 
     8778     => '\ensuremath{\approxeq}',
+    'approxeq' => '\ensuremath{\approxeq}',
     8784     => '\ensuremath{\doteq}',
     8785     => '\ensuremath{\doteqdot}',
     8786     => '\ensuremath{\fallingdotseq}',
