@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Personal Information Page
 #
-# $Id: lonaboutme.pm,v 1.157 2014/06/19 00:36:29 raeburn Exp $
+# $Id: lonaboutme.pm,v 1.158 2014/12/01 22:52:48 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -401,7 +401,7 @@ sub handler {
 
         } else {
             $r->print('\\\\\textbf{'.&mt('User Notes, Records of Face-To-Face Discussions, and Critical Messages in Course').'}\\\\'.&mt('Shared by course faculty and staff').'\\\\\\\\');
-            &Apache::lonmsgdisplay::disfacetoface($r,$cnum,$cdom, 'tex');
+            &Apache::lonmsgdisplay::disfacetoface($r,$cnum,$cdom,$target);
         }
     }
     if ($target ne 'tex') {
@@ -671,9 +671,11 @@ sub portfolio_files {
 sub build_hierarchy {
     my ($r,$cdom,$cnum,$portaccess,$is_course,$filecounts,$mode,$access_info,
         $allfileshash,$group) = @_;
+    my $clientip = $r->get_remote_host();
     foreach my $filename (sort(keys(%{$access_info}))) {
         my $access_status =
-           &Apache::lonnet::get_portfolio_access($cdom,$cnum,$filename,$group,$$access_info{$filename});
+           &Apache::lonnet::get_portfolio_access($cdom,$cnum,$filename,$group,$clientip,
+                                                 $access_info->{$filename});
         if ($portaccess eq 'both') {
             if (($access_status ne 'ok') &&
                 ($access_status !~  /^[^:]+:guest_/)) {
