@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Announce
 #
-# $Id: lonannounce.pm,v 1.87 2013/05/27 00:19:32 raeburn Exp $
+# $Id: lonannounce.pm,v 1.88 2017/02/16 18:17:49 damieng Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -117,7 +117,7 @@ sub readcalendar {
     foreach my $thiskey (keys(%$resourcedata)) {
 	if ($resourcedata->{$thiskey.'.type'}=~/^date/) {
 	    my ($course,$middle,$part,$name)=
-		($thiskey=~/^(\Q$courseid\E)\.(?:(.+)\.)*([\w\s]+)\.(\w+)$/);
+		($thiskey=~/^(\Q$courseid\E)\.(?:(.+)\.)*([\w\s\-]+)\.(\w+)$/);
 
 	    my %data = ( 'section' => &mt('All Students'));
 	    if ($middle=~/^\[(.*)\]\./) {
