@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Routines for messaging
 #
-# $Id: lonmsg.pm,v 1.239 2015/02/13 01:46:03 raeburn Exp $
+# $Id: lonmsg.pm,v 1.239.2.1 2016/08/04 22:53:55 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -397,10 +397,14 @@ sub buildmsgid {
 }
 
 sub unpackmsgid {
-    my ($msgid,$folder,$skipstatus,$status_cache)=@_;
+    my ($msgid,$folder,$skipstatus,$status_cache,$onlycid)=@_;
     $msgid=&unescape($msgid);
     my ($sendtime,$shortsubj,$fromname,$fromdomain,$count,$fromcid,
         $processid,$symb,$error) = split(/\:/,&unescape($msgid));
+    if (!defined($processid)) { $fromcid = ''; }
+    if (($onlycid) && ($onlycid ne $fromcid)) {
+        return ($sendtime,'',$fromname,$fromdomain,'',$fromcid,'',$error);
+    }
     $shortsubj = &unescape($shortsubj);
     $shortsubj = &HTML::Entities::decode($shortsubj);
     $symb = &unescape($symb);
