@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Sending messages
 #
-# $Id: lonnotify.pm,v 1.41 2014/12/11 13:15:35 raeburn Exp $
+# $Id: lonnotify.pm,v 1.42 2017/01/18 21:07:31 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -410,7 +410,7 @@ sub print_selection_form {
             my $allidlist = $idlist{$codetitles[0]};
             $jscript .= &Apache::courseclassifier::courseset_js_start($formname,$longtitles_str,$allidlist);
             $jscript .= $scripttext;
-            $jscript .= &Apache::courseclassifier::javascript_code_selections($formname,@codetitles);
+            $jscript .= &Apache::courseclassifier::javascript_code_selections($formname,\@codetitles);
         }
     }
     my @standardnames = &Apache::loncommon::get_standard_codeitems();
