@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Pick a student from the classlist
 #
-# $Id: lonpickstudent.pm,v 1.30 2011/06/07 20:18:59 www Exp $
+# $Id: lonpickstudent.pm,v 1.32 2013/07/15 16:13:22 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -108,7 +108,7 @@ function gochoose(uname,udom) {
 </script>
 ENDSCRIPT
 
-    $r->print('<form>');
+    $r->print('<form action="">');
     if ($allowed && (!$env{'form.roles'})) {
 # -------------------------------------------------------- Get course personnel
 	$r->print('<h3>'.$env{'course.'.$env{'request.course.id'}.'.description'}.
@@ -121,7 +121,7 @@ ENDSCRIPT
 		my ($puname,$pudom)=split(/\:/,$user);
 		$r->print(&Apache::loncommon::start_data_table_row().
 			  '<td>'.
-			  '<input type="button" value="'.&mt('Select').'" onClick="gochoose('.
+			  '<input type="button" value="'.&mt('Select').'" onclick="gochoose('.
 			  "'".$puname."','".$pudom."')".'" /></td><td>'.$role.'</td><td>'.
 			  &Apache::loncommon::aboutmewrapper(&Apache::loncommon::plainname($puname,$pudom),$puname,$pudom).'</td>'.
 			  &Apache::loncommon::end_data_table_row());
@@ -202,7 +202,7 @@ ENDSCRIPT
                         }
 		        $result .=&Apache::loncommon::start_data_table_row().
 		    	          '<td>'.
-			          '<input type="button" value="'.&mt('Select').'" onClick="gochoose('.
+			          '<input type="button" value="'.&mt('Select').'" onclick="gochoose('.
 			          "'".$uname."','".$udom."')".'" /></td>'.
 			          '<td><tt>'.$uname.'</tt></td><td> <tt>'.$udom.
 			          '</tt></td><td>'.
@@ -260,7 +260,7 @@ ENDSCRIPT
 	    my ($uname,$udom) = split(':',$user);
 	    $r->print(&Apache::loncommon::start_data_table_row().
 		      '<td>'.
-		      '<input type="button" value="'.&mt('Select').'" onClick="gochoose('.
+		      '<input type="button" value="'.&mt('Select').'" onclick="gochoose('.
 		      "'".$uname."','".$udom."')".'" /></td>'.
 		      '<td><tt>'.$uname.'</tt></td>'.
 		      '<td><tt>'.$udom.'</tt></td><td>'.
