@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Search for a user
 #
-# $Id: lonpickuser.pm,v 1.5 2011/01/05 18:39:38 raeburn Exp $
+# $Id: lonpickuser.pm,v 1.6 2016/09/05 01:46:08 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -215,7 +215,7 @@ ENDSET
 
     my $cancreate =
         &Apache::lonuserutils::can_create_user($dom,$context,$usertype);
-    my $userpicker =
+    my ($userpicker,$cansearch) =
        &Apache::loncommon::user_picker($dom,\%srch,$forcenewuser,
                                        'document.userpicker',$cancreate,
                                        $usertype,$context);
@@ -228,7 +228,9 @@ ENDSET
                        $env{'form.coursedom'}.'" />'."\n".
                        &set_opener_elems();
     unless ($env{'form.phase'} eq 'define_newuser') { 
-        $r->print(<<"ENDBLOCK");
+        if ($cansearch) {
+            
+            $r->print(<<"ENDBLOCK");
 <h3>$headertext</h3>
 <form action="/adm/pickuser" method="post" name="userpicker">
 $opener_elems
@@ -237,6 +239,14 @@ $userpicker
 <input name="userrole" type="button" value="$srchbutton" onclick="javascript:validateEntry(document.userpicker)" />
 </form>
 ENDBLOCK
+        } else {
+            $r->print(<<"ENDBLOCK");
+<form action="/adm/pickuser" method="post" name="userpicker">
+$opener_elems
+<input type="hidden" name="phase" value="get_user_info" />
+</form>
+ENDBLOCK
+        }
     }
     if (($env{'form.phase'} eq 'get_user_info') && ($env{'form.srchterm'} ne '')) {
         $r->print('<hr /><div>'.&mt('Searching ...').'</div>');
