@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Preferences
 #
-# $Id: lonpreferences.pm,v 1.196.4.16 2015/03/12 02:58:33 raeburn Exp $
+# $Id: lonpreferences.pm,v 1.196.4.23 2016/09/19 03:21:20 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -160,11 +160,13 @@ sub texenginechanger {
     my $domain     = $env{'user.domain'};
     my %userenv = &Apache::lonnet::get('environment',['texengine']);
     my $texengine=$userenv{'texengine'};
+    if (lc($texengine) eq 'jsmath') {
+        $texengine = 'MathJax';
+    }
 
     my %mathchoices=('' => 'Default',
 		     'tth' => 'tth (TeX to HTML)',
 		     #'ttm' => 'TeX to MathML',
-		     'jsMath' => 'jsMath',
                      'MathJax' => 'MathJax',
 		     'mimetex' => 'mimetex (Convert to Images)',
                      'raw' => 'Raw (Screen Reader)'
@@ -176,7 +178,6 @@ sub texenginechanger {
                'texengine',
                \%mathchoices);
     my $MathJax_start=&Apache::lontexconvert::MathJax_header();
-    my $jsMath_start=&Apache::lontexconvert::jsMath_header();
     my %lt=&Apache::lonlocal::texthash(
       'headline' => 'Change how math is displayed',
       'preftxt'  => 'Preferred method to display math',
@@ -184,26 +185,10 @@ sub texenginechanger {
       'exmpl'    => 'Examples',
       'mathjax'  => 'MathJax:',
       'mathjaxinfo' =>  'MathJax provides rendered equations whose source code can be extracted in TeX and MathML formats by right clicking the equation.',
-      'jsmath'   => 'jsMath:',
       'tth'      => 'tth (TeX to HTML):',
       'mimetex'  => 'mimetex (Convert to Images):',
     );
 
-    my $jsMathWarning='<p>'
-                     .'<div class="LC_warning">'
-                     .&mt("It looks like you don't have the TeX math fonts installed.")
-                     .'</div>'
-                     .'<div>'
-                     .&mt('The jsMath example on this page may not look right without them. '
-                         .'The [_1]jsMath Home Page[_2] has information on how to download the '
-                         .'needed fonts. In the meantime, jsMath will do the best it can '
-                         .'with the fonts you have, but it may not be pretty and some equations '
-                         .'may not be rendered correctly.'
-                         ,'<a href="http://www.math.union.edu/locate/jsMath/" target="_blank">'
-                         ,'</a>')
-                     .'</div>'
-                     .'</p>';
-
     $r->print(<<ENDLSCREEN);
 <h2>$lt{'headline'}</h2>
 <form name="prefs" action="/adm/preferences" method="post">
@@ -226,18 +211,6 @@ $lt{'exmpl'}
 $lt{'mathjaxinfo'}
 </p>
 
-<h3>$lt{'jsmath'}</h3> 
-<p>
-$jsMath_start
-<script type="text/javascript" language="JavaScript">
-if (jsMath.nofonts == 1) {
-    document.writeln($jsMathWarning);
-}
-
-</script>
-<iframe src="/res/adm/pages/math_example.tex?inhibitmenu=yes&texengine=jsMath" width="400" height="150"></iframe>
-</p>
-
 <h3>$lt{'mimetex'}</h3>
 <p>
 <iframe src="/res/adm/pages/math_example.tex?inhibitmenu=yes&texengine=mimetex" width="400" height="150"></iframe>
@@ -248,9 +221,6 @@ if (jsMath.nofonts == 1) {
 <iframe src="/res/adm/pages/math_example.tex?inhibitmenu=yes&texengine=tth" width="400" height="150"></iframe>
 </p>
 ENDLSCREEN
-    if ($env{'environment.texengine'} ne 'jsMath') {
-	$r->print('<script type="text/javascript" language="JavaScript">jsMath.Process()</script>');
-    }
 }
 
 
@@ -261,6 +231,9 @@ sub verify_and_change_texengine {
 # Screenname
     my $newtexengine  = $env{'form.texengine'};
     $newtexengine=~s/[^\-\w]//g;
+    if (lc($newtexengine) eq 'jsmath') {
+        $newtexengine = 'MathJax';
+    }
     if ($newtexengine eq 'ttm') {
 	&Apache::lonnet::appenv({'browser.mathml' => 1});
     } else {
@@ -1263,6 +1236,12 @@ sub passwordchanger {
         $r->print(Apache::loncommon::start_page('Personal Data'));
         $r->print(Apache::lonhtmlcommon::breadcrumbs('Change Password'));
     }
+    my ($blocked,$blocktext) =
+        &Apache::loncommon::blocking_status('passwd');
+    if ($blocked) {
+        $r->print('<p class="LC_warning">'.$blocktext.'</p>');
+        return;
+    }
     if ((!defined($caller)) || ($caller eq 'preferences')) {
         $user = $env{'user.name'};
         $domain = $env{'user.domain'};
@@ -1369,21 +1348,18 @@ sub jscript_send {
         uextkey=this.document.client.elements.ukey_cpass.value;
         lextkey=this.document.client.elements.lkey_cpass.value;
         initkeys();
-
-        this.document.pserver.elements.currentpass.value
-            =crypted(this.document.client.elements.currentpass.value);
-
+        this.document.pserver.elements.currentpass.value =
+            getCrypted(this.document.client.elements.currentpass.value);
         uextkey=this.document.client.elements.ukey_npass1.value;
         lextkey=this.document.client.elements.lkey_npass1.value;
         initkeys();
         this.document.pserver.elements.newpass_1.value
-            =crypted(this.document.client.elements.newpass_1.value);
-
+            =getCrypted(this.document.client.elements.newpass_1.value);
         uextkey=this.document.client.elements.ukey_npass2.value;
         lextkey=this.document.client.elements.lkey_npass2.value;
         initkeys();
         this.document.pserver.elements.newpass_2.value
-            =crypted(this.document.client.elements.newpass_2.value);
+            =getCrypted(this.document.client.elements.newpass_2.value);
 |;
     if ($caller eq 'reset_by_email') {
         $output .= qq|
@@ -1398,6 +1374,7 @@ sub jscript_send {
     $ output .= qq|
         this.document.pserver.submit();
     }
+
 </script>
 |;
 }
@@ -1417,13 +1394,19 @@ sub client_form {
     my $output = '<form name="client" action="">'
                 .&Apache::lonhtmlcommon::start_pick_box();
     if ($caller eq 'reset_by_email') {
+        my $mobileargs;
+        (undef,undef,undef,undef,undef,undef,my $clientmobile) =
+            &Apache::loncommon::decode_user_agent();
+        if ($clientmobile) {
+            $mobileargs = 'autocapitalize="off" autocorrect="off" ';
+        }
         $output .= &Apache::lonhtmlcommon::row_title(
                        '<label for="email">'.$lt{'email'}.'</label>')
-                  .'<input type="text" name="email" size="30" />'
+                  .'<input type="text" name="email" size="30" '.$mobileargs.'/>'
                   .&Apache::lonhtmlcommon::row_closure()
                   .&Apache::lonhtmlcommon::row_title(
                        '<label for="uname">'.$lt{'username'}.'</label>')
-                  .'<input type="text" name="uname" size="15" />'
+                  .'<input type="text" name="uname" size="20" '.$mobileargs.'/>'
                   .'<input type="hidden" name="currentpass" value="'.$currentpass.'" />'
                   .&Apache::lonhtmlcommon::row_closure()
                   .&Apache::lonhtmlcommon::row_title(
@@ -1433,16 +1416,16 @@ sub client_form {
     } else {
         $output .= &Apache::lonhtmlcommon::row_title(
                        '<label for="currentpass">'.$lt{'currentpass'}.'</label>')
-                  .'<input type="password" name="currentpass" size="10"/>'
+                  .'<input type="password" name="currentpass" size="20"/>'
                   .&Apache::lonhtmlcommon::row_closure();
     }
     $output .= &Apache::lonhtmlcommon::row_title(
                    '<label for="newpass_1">'.$lt{'newpass'}.'</label>')
-              .'<input type="password" name="newpass_1" size="10" />'
+              .'<input type="password" name="newpass_1" size="20" />'
               .&Apache::lonhtmlcommon::row_closure()
               .&Apache::lonhtmlcommon::row_title(
                    '<label for="newpass_2">'.$lt{'confirmpass'}.'</label>')
-              .'<input type="password" name="newpass_2" size="10" />'
+              .'<input type="password" name="newpass_2" size="20" />'
               .&Apache::lonhtmlcommon::row_closure(1)
               .&Apache::lonhtmlcommon::end_pick_box();
     $output .= '<p><input type="button" value="'.$lt{'changepass'}.'" onclick="send();" /></p>'
@@ -1491,6 +1474,12 @@ sub server_form {
 sub verify_and_change_password {
     my ($r,$caller,$mailtoken) = @_;
     my ($user,$domain,$homeserver);
+    my ($blocked,$blocktext) =
+        &Apache::loncommon::blocking_status('passwd');
+    if ($blocked) {
+        $r->print('<p class="LC_warning">'.$blocktext.'</p>');
+        return;
+    }
     if ($caller eq 'reset_by_email') {
         $user       = $env{'form.uname'};
         $domain     = $env{'form.udom'};
@@ -1877,6 +1866,58 @@ sub verify_and_change_coursepage {
     &print_main_menu($r,$message);
 }
 
+sub author_space_settings {
+    my $r = shift;
+    &Apache::lonhtmlcommon::add_breadcrumb(
+            {   href => '/adm/preferences?action=authorsettings',
+                text => 'Authoring Space Settings'});
+    my $user       = $env{'user.name'};
+    my $domain     = $env{'user.domain'};
+    my %author_roles = &Apache::lonnet::get_my_roles($user,$domain,'userroles','',['au','ca','aa']);
+    if (keys(%author_roles) > 0) {
+            $r->print(Apache::loncommon::start_page('Authoring Space Settings'));
+            $r->print(Apache::lonhtmlcommon::breadcrumbs('Authoring Space Settings'));
+            my %userenv = &Apache::lonnet::get('environment',['nocodemirror']);
+            my $constchecked='';
+            if ($env{'environment.nocodemirror'}) {
+               $constchecked=' checked="checked"';
+            }
+            my $text=&mt('By default, CodeMirror an editor with advanced functionality for editing code is activated for authors.');
+            my $cmoff=&mt('Deactivate CodeMirror. This can improve performance on slow computers and accessibility.');
+            my $change=&mt('Save');
+            $r->print(<<ENDSCREEN);
+        <form name="prefs" action="/adm/preferences" method="post">
+        <input type="hidden" name="action" value="change_authoring_settings" />
+        $text<br />
+        <label><input type="checkbox" name="cmoff"$constchecked />$cmoff</label><br />
+        <input type="submit" value="$change" />
+        </form>
+ENDSCREEN
+    }
+}
+
+sub change_authoring_settings {
+    my $r = shift;
+    my $user       = $env{'user.name'};
+    my $domain     = $env{'user.domain'};
+    my %author_roles = &Apache::lonnet::get_my_roles($user,$domain,'userroles','',['au','ca','aa']);
+    if (keys(%author_roles) > 0) {
+            my %ausettings=('environment.nocodemirror' => '');
+            if ($env{'form.cmoff'}) { $ausettings{'environment.nocodemirror'}='yes'; }
+            &Apache::lonnet::put('environment',\%ausettings);
+            &Apache::lonnet::appenv({'environment.nocodemirror' => $ausettings{'environment.nocodemirror'}});
+            my $status='';
+            if ($ausettings{'environment.nocodemirror'} eq 'yes') {
+                $status=&mt('on');
+            } else {
+                $status=&mt('off');
+            }
+            my $message=&Apache::lonhtmlcommon::confirm_success(&mt('Set [_1] to [_2]','<i>'.&mt('Deactivate CodeMirror in Authoring Space').'</i>','<tt>'.$status.'</tt>'));
+            $message=&Apache::loncommon::confirmwrapper($message);
+            &print_main_menu($r,$message);
+    }
+}
+
 sub lockednameschanger {
     my $r = shift;
     &Apache::lonhtmlcommon::add_breadcrumb(
@@ -2137,6 +2178,18 @@ push(@{ $menu[4]->{items} }, {
 	});
 
     }
+
+    my %author_coauthor_roles = &Apache::lonnet::get_my_roles($user,$domain,'userroles','',['au','ca','aa']);
+    if (keys(%author_coauthor_roles) > 0) {
+        push(@{ $menu[4]->{items} }, {
+            linktext => 'Authoring Space Configuration',
+            url => '/adm/preferences?action=authorsettings',
+            permission => 'F',
+            icon => 'codemirror.png',
+            linktitle => 'Settings for your authoring space.',
+        });
+    }
+
     if (&can_toggle_debug()) {
 push(@{ $menu[4]->{items} }, {
 	linktext => 'Toggle Debug Messages (Currently '.($env{'user.debug'} ? 'on)' : 'off)'),
@@ -2192,7 +2245,7 @@ sub handler {
     }elsif($env{'form.action'} eq 'changepass'){
         &passwordchanger($r);
     }elsif($env{'form.action'} eq 'verify_and_change_pass'){
-        &verify_and_change_password($r);
+        &verify_and_change_password($r,'preferences');
     }elsif($env{'form.action'} eq 'changescreenname'){
         &screennamechanger($r);
     }elsif($env{'form.action'} eq 'verify_and_change_screenname'){
@@ -2245,6 +2298,10 @@ sub handler {
         &coursedisplaychanger($r);
     }elsif($env{'form.action'} eq 'verify_and_change_coursepage'){
         &verify_and_change_coursepage($r);
+    }elsif($env{'form.action'} eq 'authorsettings'){
+        &author_space_settings($r);
+    }elsif($env{'form.action'} eq 'change_authoring_settings'){
+        &change_authoring_settings($r);
     }elsif($env{'form.action'} eq 'debugtoggle'){
         if (&can_toggle_debug()) {
             &toggle_debug();
