@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # RSS Feeder
 #
-# $Id: lonrss.pm,v 1.53 2013/07/15 14:32:44 bisitz Exp $
+# $Id: lonrss.pm,v 1.53.2.2 2017/01/21 22:36:45 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -128,8 +128,8 @@ sub advertisefeeds {
     }
     if ($feeds) {
 	return '<h4>'.&mt('Available RSS Feeds and Blogs').'</h4><ul>'.$feeds.'</ul>';
-    } else {
-        return '';
+    } elsif (!$edit) {
+        return '<h4>'.&mt('No available RSS Feeds and Blogs').'</h4>';
     }
 }
 
