@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Source Code handler
 #
-# $Id: lonsource.pm,v 1.32 2014/02/11 15:49:15 bisitz Exp $
+# $Id: lonsource.pm,v 1.35 2015/05/25 15:36:11 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -52,7 +52,8 @@ sub make_link {
 sub stage_2 {
     my ($r, $filename, $listname) = @_;
     my ($author)=($filename=~/\/res\/[^\/]+\/([^\/]+)\//);
-    $r->print(&Apache::loncommon::start_page('Copy Problem Source Code to Authoring Space')
+    $r->print(&Apache::loncommon::start_page('Copy Problem Source Code to Authoring Space',undef,
+                                             {'only_body' => 1,})
              .&mt('Please enter the directory that you would like the source code to go into.')
              .'<p>'
              .&mt('Note: the path is in reference to the root of your Authoring Space,'
@@ -64,7 +65,8 @@ sub stage_2 {
               <input type="hidden" name="action" value="copy_stage" />
               <input type="text" size="50" name="newpath" value="/'.&mt('shared_source').'/'.$author.'" />&nbsp;
               <input type="submit" value="'.&mt('Copy').'" />
-              </form>');
+              </form>'.
+              &Apache::loncommon::end_page());
     return OK;
 }
 
@@ -86,77 +88,65 @@ sub copy_author {
 sub copy_stage {
     my ($r, $filename, $listname, $newpath) = @_;
 
-#Figure out if we are author or co-author
-    my ($role,$author_name,$domain)=&copy_author();
-
-# Construct path to copy and filter out any possibly nasty stuff
-    my $path_to_new_file = $r->dir_config('lonDocRoot').
-                           "/priv/$domain/$author_name/$newpath/$listname";
-    $path_to_new_file=~s/\.\.//g;
-    $path_to_new_file=~s/\~//g;
-    $path_to_new_file=~s/\/+/\//g;
-
-#Just checking again for access as we want to make sure that it is really ok now that we have the real path
-
-    my ($uname,$udom)= &Apache::lonnet::constructaccess($path_to_new_file);
-
-    if (!$uname || !$udom) {
-	$r->print(&Apache::loncommon::start_page('Not Allowed'));
-	$r->print(&mt('Not allowed to create file [_1]', $path_to_new_file));
-	$r->print(&Apache::loncommon::end_page());
-	return;
-    }
+    my ($path_to_new_file,$uname,$udom) = &get_path_to_newfile($r,$newpath,$listname);
 
     #allowed
-    $r->print(&Apache::loncommon::start_page('Copying Source'));
-    my $result = &Apache::loncfile::exists($uname, $udom, $path_to_new_file);
-    $r->print($result);
-    if(($result) && ($result =~ m|published|) ) {
-	&delete_copy_file($r, $newpath, $filename, $path_to_new_file, '1');
-    } elsif(($result) && ($result =~ m|exists!|)) {
-	&confirm($r, $newpath, $filename, $path_to_new_file);
-    } else {
-	&copy_file($r, $newpath, $filename, $path_to_new_file);
+    if ($path_to_new_file) {
+        $r->print(&Apache::loncommon::start_page('Copying Source',undef,{'only_body' => 1}));
+        my $result = &Apache::loncfile::exists($uname, $udom, $path_to_new_file);
+        $r->print($result);
+        if (($result) && ($result =~ /published/)) {
+	    &delete_copy_file($r, $newpath, $filename, $path_to_new_file, '1');
+        } elsif (($result) && ($result =~ /exists\!/)) {
+	    &confirm($r, $newpath, $filename, $listname);
+        } else {
+	    &copy_file($r, $newpath, $filename, $path_to_new_file);
+        }
+        $r->print(&Apache::loncommon::end_page());
     }
-    
-    $r->print(&Apache::loncommon::end_page());
+    return;
 }
 
 sub confirm {
-    my ($r, $newpath, $filename, $path_to_new_file) = @_;
+    my ($r, $newpath, $filename, $listname) = @_;
     $r->print('<b>'.&mt('Press delete to remove file and replace it with a copy of the source you are viewing.').'</b><br /><br />');
     $r->print('<form name="delete_confirm" action="/adm/source" target="_parent" method="post">
               <input type="hidden" name="filename" value="'.$filename.'" />
-              <input type="hidden" name="path" value="'.$path_to_new_file.'" />
+              <input type="hidden" name="listname" value="'.$listname.'" />
               <input type="hidden" name="newpath" value="'.$newpath.'" />
               <input type="hidden" name="action" value="delete_confirm" />
-
               <input type="submit" value="Delete" />
               </form>');
+    return;
 }
 
 sub delete_copy_file {
     my ($r, $newpath, $filename, $path_to_new_file, $type) = @_;
-    if($type eq '1') {
+    if ($type eq '1') {
         $r->print('<p><span class="LC_warning">'
                  .&mt('Cannot delete non-obsolete published file.')
                  .'</span><br />'
                  .&mt('Please use the code view in previous window to use shared code.')
                  .'<br /><br />');
-        $r->print('<input type="button" value="'.&mt('Close Window').'" name="close"'
+        $r->print('<form name="delete_done" action="/adm/source" target="_parent" method="post">'
+                 .'<input type="button" value="'.&mt('Close Window').'" name="close"'
                  .' onclick="window.close()" />'
-                 .'</p>');
+                 .'</form></p>');
+        return;
     } else {
-        if(-e $path_to_new_file) {
-            unless(unlink($path_to_new_file)) {
+        $r->print(&Apache::loncommon::start_page('Copying Source',undef,{'only_body' => 1}));
+        if (-e $path_to_new_file) {
+            unless (unlink($path_to_new_file)) {
                 $r->print('<p class="LC_error"">'.&mt('Error:').' '.$!.'</p>');
                 return 0;
             }
         } else {
-            $r->print('<p class="LC_error">'.&mt('No such file').'</p></form>');
+            $r->print('<p class="LC_error">'.&mt('No such file').'</p>');
             return 0;
         }
         &copy_file($r, $newpath, $filename, $path_to_new_file);
+        $r->print(&Apache::loncommon::end_page());
+        return;
     }
 }
 
@@ -196,8 +186,12 @@ sub copy_file {
         print $fs $file_output;
     }
     $r->print("<br /><br />");
-    $r->print('<input type="button" value="'.&mt('Close Window').'" name="close" onclick="window.close()" />');
+    $r->print('<form name="copied_file" action="/adm/source" target="_parent" method="post">'
+              .'<input type="button" value="'
+              .&mt('Close Window').'" name="close" onclick="window.close()" />'
+              .'</form>');
     #Some 1.3'ish feature is to include the derivative feature, will go here..'
+    return;
 }
 
 sub print_item {
@@ -299,12 +293,48 @@ sub includemeta {
     }
 }
 
+sub get_path_to_newfile {
+    my ($r,$newpath,$listname) = @_;
+
+    #Figure out if we are author or co-author
+    my ($role,$author_name,$domain) = &copy_author();
+
+    # Construct path to copy and filter out any possibly nasty stuff
+    my $path = $r->dir_config('lonDocRoot')."/priv/$domain/$author_name/";
+    my $path_to_new_file = $path."$newpath/$listname";
+    $path_to_new_file=~s/\.\.//g;
+    $path_to_new_file=~s/\~//g;
+    $path_to_new_file=~s/\/+/\//g;
+
+    #Just checking again for access as we want to make sure that it is really ok
+    #now that we have the real path
+
+    my ($uname,$udom)= &Apache::lonnet::constructaccess($path_to_new_file);
+
+    if (!$uname || !$udom) {
+        $r->print(&Apache::loncommon::start_page('Not Allowed',undef,{'only_body' => 1}));
+        $r->print(&mt('Not allowed to create file [_1]', $path_to_new_file));
+        $r->print(&Apache::loncommon::end_page());
+        if (wantarray) {
+            return();
+        } else {
+            return;
+        }
+    }
+    if (wantarray) {
+        return ($path_to_new_file,$uname,$udom);
+    } else {
+        return $path_to_new_file;
+    }
+}
+
 sub handler {
     my $r=shift;
     &Apache::loncommon::get_unprocessed_cgi($ENV{'QUERY_STRING'},
                                             ['filename','listname']);
     my $filename = $env{'form.filename'};
     my $listname = $env{'form.listname'};
+
     my $source = &Apache::lonnet::metadata($filename,'sourceavail');
     if ($source ne 'open') {
         $env{'user.error.msg'}="$filename:cre:1:1:Source code not available";
@@ -318,6 +348,7 @@ sub handler {
         $env{'user.error.msg'}="$filename:cre:1:1:Access to source code denied";
         return HTTP_NOT_ACCEPTABLE;
     }
+    my $newpath = $env{'form.newpath'};
 
     &Apache::loncommon::content_type($r,'text/html');
     $r->send_http_header;
@@ -325,9 +356,12 @@ sub handler {
     if ($env{'form.action'} eq 'stage2') {
         &stage_2($r,$filename,$listname);
     } elsif($env{'form.action'} eq 'copy_stage') {
-        &copy_stage($r,$filename,$listname,$env{'form.newpath'});
+        &copy_stage($r,$filename,$listname,$newpath);
     } elsif($env{'form.action'} eq 'delete_confirm') {
-        &delete_copy_file($r,$env{'form.newpath'},$filename, $env{'form.path'}, '0');
+        my $path_to_new_file = &get_path_to_newfile($r,$newpath,$listname);
+        if ($path_to_new_file) {
+            &delete_copy_file($r, $newpath, $filename, $path_to_new_file, '0');
+        }
     } else {
         &print_item($r,$filename,$listname);
     }
