@@ -1,5 +1,5 @@
 #
-# $Id: lonwhatsnew.pm,v 1.105.2.10 2015/03/12 03:28:51 raeburn Exp $
+# $Id: lonwhatsnew.pm,v 1.105.2.14 2017/05/19 19:55:09 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -62,17 +62,36 @@ sub handler {
     my $command = $env{'form.command'};
     my $refpage = $env{'form.refpage'};
 
-    my %checkallowed = ( coursenormalmail => 1,
-			 coursecritmail => 1, );
+    my $cdom = $env{'course.'.$env{'request.course.id'}.'.domain'};
+    my $crs = $env{'course.'.$env{'request.course.id'}.'.num'};
+
+    my ($isadhoc,%checkallowed);
+
+    if ($env{'request.role'} =~ m{^(cc|co)/}) {
+        my $rolecode = $1;
+        if ($env{"environment.internal.$cdom.$crs.$env{'request.role'}.adhoc"}) {
+            $isadhoc = 1;
+        }
+    } elsif ($env{'request.role'} =~ m{^cr/$cdom/$cdom\-domainconfig/(\w+)\./}) {
+        my $rolename = $1;
+        if ($env{"environment.internal.$cdom.$crs.cr/$cdom/$cdom-domainconfig/$rolename.adhoc"}) {
+            $isadhoc = 1;
+        }
+    }
+    unless ($isadhoc) {
+        %checkallowed = ( coursenormalmail => 1,
+                          coursecritmail => 1,);
+    }
     foreach my $perm_check (['whn','whatsnew',1],
 			    ['pch','coursediscussion',1],
 			    ['mgr','handgrading',1],
 			    ['vgr','abovethreshold',1],
-			    ['opa','haserrors',1],
-			    ['mdc','versionchanges',0],
+			    ['vgr','haserrors',1],
+			    ['whn','versionchanges',1],
                             ['vcl','newroles',1],
                             ['vcl','oldroles',1],
                             ['whn','crslogin',1],
+                            ['mgr','resetcounters',1],
 			    ) {
 	my ($perm,$key,$check_section) = @{ $perm_check };
 	my $scope = $env{'request.course.id'};
@@ -156,7 +175,7 @@ sub handler {
             ("What's New?",#'Course_Action_Items_Display'
 	     ));
     }
-    &display_main_box($r,$command,$refpage,\%checkallowed);
+    &display_main_box($r,$command,$refpage,\%checkallowed,$cdom,$crs);
     return OK;
 }
 
@@ -167,7 +186,7 @@ sub handler {
 #------------------------------
                                                                                 
 sub display_main_box {
-    my ($r,$command,$refpage,$checkallowed) = @_;
+    my ($r,$command,$refpage,$checkallowed,$cdom,$crs) = @_;
     my $domain=&Apache::loncommon::determinedomain();
     my $function = &Apache::loncommon::get_users_function();
     my $lctype = lc(&Apache::loncommon::course_type());
@@ -214,13 +233,10 @@ sub display_main_box {
                      userpref => 'your general user preferences',
                      coursespecific => "specific setting for this $lctype",
                    );
-    my $cdom = $env{'course.'.$env{'request.course.id'}.'.domain'};
-    my $crs = $env{'course.'.$env{'request.course.id'}.'.num'};
 
     if (($command eq 'chgthreshold') 
 	&& $checkallowed->{'abovethreshold'}) {
-        &display_threshold_config($r,$refpage,\%threshold_titles,
-                                                                   $cdom,$crs);
+        &display_threshold_config($r,$refpage,\%threshold_titles,$cdom,$crs);
     } elsif (($command eq 'chginterval') 
 	     && $checkallowed->{'versionchanges'}) {
         &display_interval_config($r,$refpage,\%interval_titles,'versions');
@@ -441,7 +457,7 @@ sub display_actions_box {
     $r->print(&Apache::loncommon::head_subbox($header));
 
     if ($command eq 'reset') {
-        $result = &process_reset($cdom,$crs);
+        $result = &process_reset($cdom,$crs,$checkallowed);
     } elsif ($command eq 'update') {
         $result = &process_update($uname,$udom,$threshold_titles);
     } elsif ($command eq 'newinterval') {
@@ -573,6 +589,18 @@ sub display_actions_box {
 	    '<br />',$threshold{'numstudents'});
 
     my @actionorder = ('handgrading','haserrors','abovethreshold','versionchanges','coursediscussion','coursenormalmail','coursecritmail','newroles','oldroles','crslogin');
+    my %actioncolumn = (
+                         handgrading      => 'left',
+                         haserrors        => 'left',
+                         abovethreshold   => 'left',
+                         versionchanges   => 'left',
+                         coursediscussion => 'right',
+                         coursenormalmail => 'right',
+                         coursecritmail   => 'right',
+                         newroles         => 'right',
+                         oldroles         => 'right',
+                         crslogin         => 'right',
+                       );
 
     foreach my $key (keys(%{$checkallowed})) {
 	if ($key =~ /_section$/) { next; }
@@ -596,7 +624,7 @@ sub display_actions_box {
 
     my $itemserror;
     if ($needitems) {
-        $itemserror = &getitems(\%unread,\%ungraded,\%bombed,\%triggered,\%changed,\@newdiscussions,\@tograde,\@bombs,\@warnings,\%threshold,$cdom,$crs,\%res_title,\%show,$starttime,$countunread);
+        $itemserror = &getitems(\%unread,\%ungraded,\%bombed,\%triggered,\%changed,\@newdiscussions,\@tograde,\@bombs,\@warnings,\%threshold,$cdom,$crs,\%res_title,\%show,$starttime,$countunread,$checkallowed);
     }
     my $classlist;
     if ($show{'oldroles'} || $show{'newroles'} || $show{'crslogin'}) {
@@ -638,12 +666,13 @@ sub display_actions_box {
             $totalboxes ++;
         }
     }
-    my $halfway = 4;
+    my $currcolumn = 'left';
 #    my $halfway = int($totalboxes/2) + $totalboxes%2;
     foreach my $actionitem (@actionorder) {
-        if ($$checkallowed{$actionitem}) {
-            if ($displayed == $halfway) {
+        if ($checkallowed->{$actionitem}) {
+            if (($actioncolumn{$actionitem} eq 'right') && ($currcolumn eq 'left')) { 
                 $r->print('</td><td>&nbsp;</td><td class="LC_right_col" >');
+                $currcolumn = 'right'; 
             }
             &display_launcher($r,$actionitem,$refpage,$checkallowed,\%show,\%headings,\%res_title,\@tograde,\%ungraded,\@bombs,\%bombed,\%changed,\@warnings,\%triggered,\@newdiscussions,\%unread,$msgcount,\@newmsgs,$critmsgcount,\@critmsgs,\%interval,$countunread,\%expired,$expirecount,\%activated,$activecount,$crstype,$itemserror,\%loggedin,$logincount,$classlist);
             $displayed ++; 
@@ -914,7 +943,7 @@ sub display_launcher {
                 &display_versionchanges($r,$changed,$res_title,$interval->{'versions'},$itemserror);
             } elsif ($action eq 'abovethreshold') { # DEGDIFF/AV. TRIES TRIGGERS
                 &display_abovethreshold($r,$refpage,$warnings,$triggered,
-					$res_title,$itemserror);
+					$res_title,$itemserror,$checkallowed);
             } elsif ($action eq 'coursediscussion') { # UNREAD COURSE DISCUSSION
                 &display_coursediscussion($r,$newdiscussions,$unread,
                                 $countunread,$res_title,$itemserror);
@@ -941,7 +970,7 @@ sub display_launcher {
 sub getitems {
     my ($unread,$ungraded,$bombed,$triggered,$changed,$newdiscussions,
         $tograde,$bombs,$warnings,$threshold,$cdom,$crs,$res_title,$show,
-        $starttime,$countunread) = @_;
+        $starttime,$countunread,$checkallowed) = @_;
     my $navmap = Apache::lonnavmaps::navmap->new();
     if (!defined($navmap)) {
         my $itemserror = '<span class="LC_warning">'.&mt('An error occurred retrieving information about the course.').'<br />'.&mt('It is recommended that you [_1]re-select the course[_2].','<a href="/adm/roles">','</a>').'</span>';
@@ -1001,7 +1030,8 @@ sub getitems {
 # Maxtries and degree of difficulty for problem parts, unless handgradeable
         if ($$show{'abovethreshold'}) {  
             &check_thresholds($resource,$symb,\%resourcetracker,
-			      $triggered,$threshold,$warnings);
+			      $triggered,$threshold,$warnings,
+                              $checkallowed);
         }
 
     }
@@ -1075,7 +1105,8 @@ sub check_bombed {
 }
 
 sub check_thresholds {
-    my ($resource,$symb,$resourcetracker,$triggered,$threshold,$warnings) = @_;
+    my ($resource,$symb,$resourcetracker,$triggered,$threshold,$warnings,
+        $checkallowed) = @_;
 # Compile maxtries and degree of difficulty for problem parts, unless handgradeable
     my @parts = @{$resource->parts()};
     my %stats;
@@ -1141,8 +1172,12 @@ sub check_thresholds {
                      <td>'.$stats{$part}{users}.'</td>
                      <td>'.$stats{$part}{attempts}.'</td>
                      <td>'.$stats{$part}{degdiff}.'</td>
-                     <td>'.$lastreset{$part}.'</td>
-                     <td><input type="checkbox" name="'.$resetname.'" /><input type="hidden" name="'.$resettitle.'" value="'.&escape($$triggered{$symb}{title}).'" /></td>';
+                     <td>'.$lastreset{$part}.'</td>';
+                if ($checkallowed->{'resetcounters'}) {
+                    $$triggered{$symb}{text}[$partcount] .=
+                        '<td><input type="checkbox" name="'.$resetname.'" />'.
+                        '<input type="hidden" name="'.$resettitle.'" value="'.&escape($$triggered{$symb}{title}).'" /></td>';
+                }
                 $partcount ++;
             }
             $$triggered{$symb}{numparts} = $partcount;
@@ -1204,7 +1239,11 @@ sub get_current {
 }
 
 sub process_reset {
-    my ($dom,$crs) = @_;
+    my ($dom,$crs,$checkallowed) = @_;
+    if (!$checkallowed->{'resetcounters'}) {
+        return '<b>'.&mt('You do not have the required privileges to reset counters').
+               '</b><br />';
+    }
     my $result = '<b>'.&mt('Counters reset for following problems (and parts):').
                            '</b><br />';
     my @agg_types = ('attempts','users','correct');
@@ -1275,29 +1314,36 @@ sub process_update {
 
 sub getnormalmail {
     my ($newmsgs) = @_;
-# Check for unread mail in course
+# Check for unread messages in user's INBOX (which were sent in context of current course).
     my $msgcount = 0;
-
-    my @messages = sort(&Apache::lonnet::getkeys('nohist_email'));
-    foreach my $message (@messages) {
-	my $msgid=&escape($message);
-        my ($sendtime,$shortsubj,$fromname,$fromdom,$status,$fromcid)=
-            &Apache::lonmsg::unpackmsgid($msgid);
-        if (($fromcid) && ($fromcid eq $env{'request.course.id'})) {
-            if (defined($sendtime) && $sendtime!~/error/) {
-                if ($status eq 'new') {
-                $sendtime = &Apache::lonlocal::locallocaltime($sendtime);
-		    $msgcount ++;
-                    if ($shortsubj eq '') {
-                        $shortsubj = &mt('No subject');
+    my @messages = &Apache::lonnet::getkeys('nohist_email');
+    return $msgcount if (!@messages);
+    my %emailstatus = &Apache::lonnet::dump('email_status');
+    foreach my $msgid (sort(@messages)) {
+        if ((!$emailstatus{$msgid}) || ($emailstatus{$msgid} eq 'new')) {
+            my $skipstatus;
+            if ($emailstatus{$msgid} eq 'new') {
+                $skipstatus = 1;
+            }
+            my ($sendtime,$shortsubj,$fromname,$fromdom,$status,$fromcid)=
+                &Apache::lonmsg::unpackmsgid($msgid,undef,$skipstatus,undef,
+                                             $env{'request.course.id'});
+            if (($fromcid) && ($fromcid eq $env{'request.course.id'})) {
+                if (defined($sendtime) && $sendtime!~/error/) {
+                    if (($emailstatus{$msgid} eq 'new') || ($status eq 'new')) {
+                        $sendtime = &Apache::lonlocal::locallocaltime($sendtime);
+                        $msgcount ++;
+                        if ($shortsubj eq '') {
+                            $shortsubj = &mt('No subject');
+                        }
+                        push(@{$newmsgs}, {
+                            msgid    => $msgid,
+                            sendtime => $sendtime,
+                            shortsub => $shortsubj,
+                            from     => $fromname,
+                            fromdom  => $fromdom
+                            });
                     }
-                    push(@{$newmsgs}, {
-                        msgid    => $msgid,
-                        sendtime => $sendtime,
-                        shortsub => $shortsubj,
-                        from     => $fromname,
-                        fromdom  => $fromdom
-                        });
                 }
             }
         }
@@ -1307,13 +1353,14 @@ sub getnormalmail {
 
 sub getcritmail {
     my ($critmsgs) = @_; 
-# Check for critical messages in course
+# Check for critical messages which were sent in context of current course.
     my %what=&Apache::lonnet::dump('critical');
     my $result = '';
     my $critmsgcount = 0;
     foreach my $msgid (sort(keys(%what))) {
         my ($sendtime,$shortsubj,$fromname,$fromdom,$status,$fromcid)=
-            &Apache::lonmsg::unpackmsgid($msgid);
+            &Apache::lonmsg::unpackmsgid($msgid,undef,1,undef,
+                                         $env{'request.course.id'});
         if (($fromcid) && ($fromcid eq  $env{'request.course.id'})) {
             if (defined($sendtime) && $sendtime!~/error/) {
                 $sendtime = &Apache::lonlocal::locallocaltime($sendtime);
@@ -1667,7 +1714,7 @@ sub display_haserrors {
 }
 
 sub display_abovethreshold {
-    my ($r,$refpage,$warnings,$triggered,$res_title,$itemserror) = @_;
+    my ($r,$refpage,$warnings,$triggered,$res_title,$itemserror,$checkallowed) = @_;
     my %lt = &Apache::lonlocal::texthash(
                  reso => 'Resource',
                  part => 'Part',
@@ -1686,8 +1733,11 @@ sub display_abovethreshold {
                   '<input type="hidden" name="command" value="" /></td>'.
 		  '<td>'.$lt{'part'}.'</td><td>'.$lt{'nust'}.'</td>'.
 		  '<td>'.$lt{'avat'}.'</td><td>'.$lt{'dedi'}.'</td>'.
-		  '<td>'.$lt{'lare'}.'</td><td  class="LC_right_item">'.
-                  $lt{'reco'}.'</td></tr>');
+		  '<td>'.$lt{'lare'}.'</td>');
+        if ($checkallowed->{'resetcounters'}) {
+            $r->print('<td  class="LC_right_item">'.$lt{'reco'}.'</td>');
+        }
+        $r->print('</tr>');
 	my $row;
         foreach my $res (@{$warnings}) {
 	    $row++;
@@ -1719,7 +1769,9 @@ sub display_abovethreshold {
                 }
             }
         }
-        $r->print('<tr class="LC_info_row"><td colspan="7" class="LC_right_item"><br /><input type="button" name="counters" value="'.$lt{'rese'}.'" onclick="javascript:thresholdreset();" /></td></tr>');
+        if ($checkallowed->{'resetcounters'}) {
+            $r->print('<tr class="LC_info_row"><td colspan="7" class="LC_right_item"><br /><input type="button" name="counters" value="'.$lt{'rese'}.'" onclick="javascript:thresholdreset();" /></td></tr>');
+        }
     } elsif ($itemserror) {
         $r->print('<tr class="LC_empty_row"><td>'.$itemserror.'</td></tr>');
     } else {
