@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 # CGI-script to run LaTeX, dvips, ps2ps, ps2pdf etc.
 #
-# $Id: printout.pl,v 1.160 2015/03/09 19:07:09 raeburn Exp $
+# $Id: printout.pl,v 1.164 2017/01/29 23:53:55 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -40,6 +40,7 @@ use Apache::lonlocal;
 use Apache::lonmsg();
 use LONCAPA::Enrollment;
 use LONCAPA::Configuration;
+use LONCAPA;
 
 use strict;
 
@@ -201,7 +202,7 @@ my $tableofindex = $env{'cgi.'.$identifier.'.tableofindex'};
 my $advanced_role = $env{'cgi.'.$identifier.'.role'};
 my $number_of_files = $env{'cgi.'.$identifier.'.numberoffiles'}+1;
 my $student_names = $env{'cgi.'.$identifier.'.studentnames'};
-my $backref = &Apache::lonnet::unescape($env{'cgi.'.$identifier.'.backref'});
+my $backref = &unescape($env{'cgi.'.$identifier.'.backref'});
 
 
 my @names_pack=();
@@ -209,8 +210,10 @@ if ($student_names=~/_END_/) {
     @names_pack=split(/_ENDPERSON_/,$student_names);
 }
 if ($backref) {
-    print('<p>'.&mt("[_1]Return[_2] to editing resource.",
+    print('<p>'.&mt("[_1]Return[_2] to resource.",
 		    "<a href=\"$backref\"><b>","</b></a>").'</p>');
+    print('<p><a href="javascript:gopost(\'/adm/printout\',\''.$backref.'\');">'.
+        &mt("Change Printing Options").'</a></p>'."\n");
 }
 my $figfile = $texfile;
 $figfile =~ s/^(.*_printout)_\d+_\d+_\d+\.tex/$1\.dat/;
@@ -438,8 +441,13 @@ foreach $texfile (@texfile) {
 	  $name_file =~ s/\.tex/\.dvi/;
 	  my $new_name_file = $name_file;
 	  $new_name_file =~ s/\.dvi/\.ps/;
+# Explicitly include a switch for papertype, otherwise dvips will default
+# to whatever is listed first in config.ps (which in most cases is a4).
+# Historically (since 2004) LON-CAPA printing expected to use the default,
+# i.e., a papertype of a4, when the user selected letter [8 1/2 x 11 in] 
+# in the Layout options, so I follow that convention if $papera is letter.  
 	  my $papera=$paper;
-	  if ($papera eq 'letter') {$papera='';}
+	  if ($papera eq 'letter') {$papera='a4';}
 	  if ($papera ne '') {$papera='-t'.$papera;}
 	  my $extra_ps_header = $perlvar{'lonLib'} .'/includepsheader.ps';
 	  my $comma = "dvips $papera -h $extra_ps_header -Ppdf -G0 -o  $new_name_file";
