@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Allow users to self-enroll in a course
 #
-# $Id: selfenroll.pm,v 1.27.2.3 2014/04/06 14:24:40 raeburn Exp $
+# $Id: selfenroll.pm,v 1.27.2.5 2016/08/07 01:40:55 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -221,7 +221,8 @@ sub handler {
     if ($sso_url eq '') {
         $sso_url = $login_path;
     }
-    $missing_formitem = &mt('The link to the requested page could not be followed.')."\\n".&mt('The placeholder for the courseID is absent.');
+    $missing_formitem = &mt('The link to the requested page could not be followed.')."\n".&mt('The placeholder for the courseID is absent.');
+    &js_escape(\$missing_formitem);
     if ($knownuser) {
         if (keys(%curr_role)) {
             $r->print('<h3>'.&mt('Self-enrollment unavailable').'</h3>'.
@@ -438,8 +439,9 @@ sub process_self_enroll {
         if ($selfenroll_section eq 'none') {
             $usec = '';
         }
+        my $instcid;
         if ($selfenroll_registered) {
-            my ($registered,$instsec,$message) = &check_registered($cdom,$cnum);
+            my ($registered,$instsec,$instcid,$message) = &check_registered($cdom,$cnum);
             $usec = $instsec;
             if (!$registered) {
                 $r->print('<h3>'.&mt('Self-enrollment unavailable').'</h3>'.
@@ -462,7 +464,7 @@ sub process_self_enroll {
             my $enrollresult = 
                 &Apache::lonnet::modify_student_enrollment($udom,$uname,undef,undef,undef,
                         undef,undef,$usec,$selfenroll_access_end,$selfenroll_access_start,
-                       'selfenroll',undef,$cdom.'_'.$cnum,$selfenroll);
+                       'selfenroll',undef,$cdom.'_'.$cnum,$selfenroll,'selfenroll','',$instcid);
             if ($enrollresult eq 'ok') {
                 my (%userroles,%newrole,%newgroups);
                 my $role = 'st';
@@ -785,7 +787,7 @@ sub print_selfenroll_types {
 
 sub check_registered {
     my ($cdom,$cnum) = @_;
-    my ($registered,$instsec,$message);
+    my ($registered,$instsec,$instcid,$message);
     my %settings = &Apache::lonnet::get('environment',['internal.coursecode',
                                         'internal.sectionnums',
                                         'internal.crosslistings'],$cdom,$cnum);
@@ -805,6 +807,7 @@ sub check_registered {
                     if (defined($enrolled{$env{'user.name'}})) {
                         $registered = 1;
                         $instsec = $LC_code{$class};
+                        $instcid = $class;
                         last;
                     }
                 }
@@ -817,7 +820,7 @@ sub check_registered {
     } else {
         $message = &mt('As no institutional course sections are currently associated with this course, your registration status is undetermined.'); 
     }
-    return ($registered,$instsec,$message);
+    return ($registered,$instsec,$instcid,$message);
 }
 
 1;
