@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: lonstathelpers.pm,v 1.63 2010/08/04 01:56:07 raeburn Exp $
+# $Id: lonstathelpers.pm,v 1.74 2015/06/09 21:23:02 damieng Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -90,10 +90,10 @@ sub render_resource {
     my $rendered_problem = &Apache::lonnet::ssi_body($src.'?symb='.$symb);
     $rendered_problem =~ s/<\s*form\s*/<nop /g;
     $rendered_problem =~ s|(<\s*/form\s*>)|<\/nop>|g;
-    return '<table bgcolor="ffffff"><tr><td>'.
-        '<base href="'.$base.'" />'.
-        $rendered_problem.
-        '</td></tr></table>';
+    return '<div class="LC_Box">'.
+        '<h4 class="LC_hcell">'.&mt('Problem').'</h4>'.
+        '<base href="'.$base.'" />'.$rendered_problem.
+        '</div>';
 }
 
 ####################################################
@@ -135,9 +135,20 @@ Skips 'survey' problems.
 ####################################################
 ####################################################
 sub problem_selector {
-    my ($AcceptedResponseTypes,$sequence_addendum,$symbmode) = @_;
+    my ($AcceptedResponseTypes,$sequence_addendum,$symbmode,$all,$prefix,$smallbox,$onclick) = @_;
+# all: also make sequences selectable
+# prefix: prefix for all form names
+# smallbox: use smaller box
+# onclick: javascript to execute when clicked
     my $Str;
-    $Str = &Apache::loncommon::start_data_table();
+    my $jsadd='';
+    if ($onclick) {
+        $jsadd="onclick='$onclick'";
+    }
+    $Str =  &Apache::loncommon::start_scrollbox(($smallbox?'420px':'620px'),
+                                                ($smallbox?'400px':'600px'),
+                                                ($smallbox?'60px':'300px')).
+            &Apache::loncommon::start_data_table();
     my $rb_count =0;
     my ($navmap,@sequences) = 
         &Apache::lonstatistics::selected_sequences_with_assessments('all');
@@ -166,10 +177,12 @@ sub problem_selector {
                         }
                         $seq_str .=  &Apache::loncommon::start_data_table_row().
                             ($symbmode?
-                             '<td><input type="radio" id="'.$rb_count.'" name="symb" value="'.&HTML::Entities::encode($res->symb,'<>&"').'" '.$checked.' /></td>'
+                             '<td><input type="radio" id="'.$prefix.$rb_count.'" name="'.$prefix.'symb" value="'.&HTML::Entities::encode($res->symb,'<>&"').'" '.$checked.' '.
+                             $jsadd.
+                             ' /></td>'
                             :qq{<td><input type="radio" id="$rb_count" name="problemchoice" value="$value"$checked /></td>}).
-                            '<td><label for="'.$rb_count.'">'.$resptype.'</label></td>'.
-                            '<td><label for="'.$rb_count.'">'.$title.'</label>';
+                            '<td><label for="'.$prefix.$rb_count.'">'.$resptype.'</label></td>'.
+                            '<td><label for="'.$prefix.$rb_count.'">'.$title.'</label>';
                         if (scalar(@response_ids) > 1) {
                             $seq_str .= &mt('response').' '.$respid;
                         }
@@ -184,7 +197,9 @@ sub problem_selector {
         }
         if ($seq_str ne '') {
             $Str .= &Apache::loncommon::start_data_table_header_row().
-                '<th colspan="3">'.$seq->compTitle.'</th>'.
+                '<th colspan="3">'.
+                ($all?'<input type="radio" id="'.$prefix.'s'.$rb_count.'" name="'.$prefix.'symb" value="'.&HTML::Entities::encode($seq->symb,'<>&').'" '.$jsadd.' />':'').
+                $seq->compTitle.'</th>'.
                 &Apache::loncommon::end_data_table_header_row()."\n".$seq_str;
             if (defined($sequence_addendum)) {
                 $Str .= &Apache::loncommon::start_data_table_header_row().
@@ -193,8 +208,9 @@ sub problem_selector {
                     &Apache::loncommon::end_data_table_header_row()."\n";
             }
         }
+
     }
-    $Str .= &Apache::loncommon::end_data_table()."\n";
+    $Str .= &Apache::loncommon::end_data_table().&Apache::loncommon::end_scrollbox()."\n";
     return $Str;
 }
 
@@ -270,7 +286,8 @@ END
 END
     if (ref($anoncounter) eq 'HASH') {
         if (keys(%{$anoncounter}) > 0) {
-            my $anonwarning = &mt('Your selection includes both problems with and without anonymous submissions.').'\n'.&mt('You must select either only anonymous or only named problems.').'\n\n'.&mt('If a selection contains both anonymous and named parts, [_1]use the Anoymous/Named buttons to ensure selections will be either all anonymous [_1]or all named.','\n');
+            my $anonwarning = &mt('Your selection includes both problems with and without anonymous submissions.')."\n".&mt('You must select either only anonymous or only named problems.')."\n\n".&mt('If a selection contains both anonymous and named parts,[_1]use the Anonymous/Named buttons to ensure selections will be either all anonymous[_1]or all named.',"\n");
+            &js_escape(\$anonwarning);
             $checkanonjs = <<"END";
 
 <script type="text/javascript" language="JavaScript">
@@ -700,10 +717,7 @@ sub GetStudentAnswers {
     # Read in the cache (if it exists) before we start timing things.
     &Apache::lonstathelpers::ensure_proper_cache($resource->{'symb'});
     # Open progress window
-    my %prog_state=&Apache::lonhtmlcommon::Create_PrgWin
-        ($r,'Student Answer Compilation Status',
-         'Student Answer Compilation Progress', scalar(@$Students),
-         $status_type,undef,$formname,$inputname);
+    my %prog_state=&Apache::lonhtmlcommon::Create_PrgWin($r,scalar(@$Students));
     $r->rflush();
     foreach my $student (@$Students) {
         last if ($c->aborted());
@@ -988,7 +1002,7 @@ prior to every analysis lookup.
 sub ensure_proper_cache {
     my ($symb) = @_;
     my $cid = $env{'request.course.id'};
-    my $new_filename =  '/home/httpd/perl/tmp/'.
+    my $new_filename = LONCAPA::tempdir() .
         'problemanalysis_'.$cid.'_analysis_cache.db';
     if (! defined($cache_filename) ||
         $cache_filename ne $new_filename ||
@@ -1372,9 +1386,9 @@ sub limit_by_time_form {
     $Str .= '<fieldset>';
     my $timecheckbox = '<input type="checkbox" name="limit_by_time" ';
     if (&limit_by_time()) {
-        $timecheckbox .= ' checked ';
+        $timecheckbox .= 'checked="checked" ';
     } 
-    $timecheckbox .= 'OnChange="javascript:toggle_limitby_activity(this.checked);" ';
+    $timecheckbox .= 'onchange="javascript:toggle_limitby_activity(this.checked);" ';
     $timecheckbox .= ' />';
     $Str .= '<legend><label>'.&mt('[_1] Limit by time',$timecheckbox).'</label></legend>';
     $Str .= &mt('Start Time: [_1]',$startdateform).'<br />';
@@ -1476,10 +1490,7 @@ sub gather_full_student_data {
     my @Students = @Apache::lonstatistics::Students;
     #
     # Open the progress window
-    my %prog_state=&Apache::lonhtmlcommon::Create_PrgWin
-        ($r,&mt('Student Data Compilation Status'),
-         &mt('Student Data Compilation Progress'), scalar(@Students),
-         $status_type,undef,$formname,$inputname);
+    my %prog_state=&Apache::lonhtmlcommon::Create_PrgWin($r,scalar(@Students));
     #
     while (my $student = shift @Students) {
         return if ($c->aborted());
