@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 # The LearningOnline Network
 #
-# $Id: refresh_courseids_db.pl,v 1.19 2014/06/07 19:13:51 raeburn Exp $
+# $Id: refresh_courseids_db.pl,v 1.20 2016/01/27 22:23:09 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -122,7 +122,7 @@ sub recurse_courses {
         closedir(DIR);
         $depth ++;
         foreach my $item (@contents) {
-            if ($depth < 4) {
+            if (($depth < 4) && (length($item) == 1)) {
                 &recurse_courses($cdom,$dir.'/'.$item,$depth,$courseshash,
                                  $currhash,$lastaccess,$autoassign,$fh);
             } elsif ($item =~ /^$match_courseid$/) {
