@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Authoring Space Directory Lister
 #
-# $Id: lonpubdir.pm,v 1.160 2014/08/05 19:32:23 musolffc Exp $
+# $Id: lonpubdir.pm,v 1.160.2.3 2017/04/02 21:58:53 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -344,7 +344,8 @@ sub startpage {
 
     $r->print(&Apache::loncommon::head_subbox(
                      '<div style="float:right;padding-top:0;margin-top;0">'
-                    .&Apache::lonhtmlcommon::display_usage($current_disk_usage,$disk_quota)
+                    .&Apache::lonhtmlcommon::display_usage($current_disk_usage,
+                                                           $disk_quota,'authoring')
                     .'</div>'
                     .&Apache::loncommon::CSTR_pageheader()));
 
@@ -523,7 +524,7 @@ sub dircontrols {
     </form>
   </div>
 
-  <div>
+  <div style="padding-bottom: 2px">
     <form name="upublisher" enctype="multipart/form-data" method="post" action="/adm/upload" target="_parent">
       <fieldset>
         <legend>$lt{'updc'}</legend>
@@ -562,7 +563,44 @@ sub dircontrols {
                     <option value="newtaskfile">$lt{'nbt'}:</option>
                     <option value="newlibraryfile">$lt{'nlib'}:</option>
 	            <option value="newdir">$lt{'nsub'}:</option>
-		  </select>&nbsp;<input type="text" name="newfilename" value="$lt{'type'}" onfocus="if (this.value == '$mytype') this.value=''" />&nbsp;<input type="button" value="Go" onclick="validate_go();" />
+		  </select>&nbsp;<input type="text" name="newfilename" placeholder="$lt{'type'}" value="" onfocus="if (this.value == is.empty()) this.value=''" />&nbsp;<input type="button" value="Go" onclick="validate_go();" />
+                <br />
+                <span>Quickactions:
+                 <input type="hidden" name="mode"/>
+                 <a href="javascript:void(0)" onclick="javascript:validate_action('blank')">
+                    <img src="/adm/lonIcons/unknown.gif" title="Create blank problem file"></a>
+                 <a href="javascript:void(0)" onclick="javascript:validate_action('problemtempl')">
+                    <img src="/adm/lonIcons/problem.gif" title="Create new problem from template"></a>
+                 <a href="javascript:void(0)" onclick="javascript:validate_action('blankhtml')">
+                    <img src="/adm/lonIcons/html.gif" title="Create new blank HTML file"></a>
+                 <a href="javascript:void(0)" onclick="javascript:validate_action('folder')">
+                    <img src="/adm/lonIcons/navmap.folder.closed.gif" title="Create new subdirectory"></a>
+                </span>
+                 <script type="text/javascript">
+                     function validate_action(action){
+
+                         if (document.getElementsByName(\'newfilename\')[0].value != \'\'){
+                             if (action == "blank") {
+                                                                 document.fileaction.action.value=\'newproblemfile\';
+                                                                 document.fileaction.mode.value=\'blank\';
+                                                         } else if (action == "problemtempl") {
+                                                                 document.fileaction.action.value=\'newproblemfile\';
+                                 validate_go();
+                             } else if (action == "blankhtml") {
+                                 document.fileaction.action.value=\'newhtmlfile\';
+                                 validate_go();
+                             } else if (action == "folder") {
+                                 document.fileaction.action.value=\'newdir\';
+                                 document.fileaction.mode.value=\'folder\';
+                             }
+                             fileaction.submit();
+                         } else {
+                             alert(\'Please specify file name.\');
+                             // TODO: ask for filename? if so, do some refactoring
+
+                         }
+                     }
+                 </script>
 		 </span>
       </fieldset>
     </form>
