@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Unauthorized to access construction space
 #
-# $Id: lonunauthorized.pm,v 1.13.2.2 2011/11/30 18:38:58 raeburn Exp $
+# $Id: lonunauthorized.pm,v 1.17 2013/06/07 16:07:49 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -32,7 +32,6 @@ use strict;
 use Apache::Constants qw(:common);
 use Apache::loncommon;
 use Apache::lonnet;
-use Apache::loncacc;
 use Apache::lonlocal;
 use LONCAPA();
 use HTML::Entities();
@@ -46,18 +45,18 @@ sub handler {
 # ------------------------------------------------------------ Print the screen
 # Figure out who the user is and what they wanted to access
 
-    my ($ownername,$ownerdomain);
+    my ($ownername,$ownerdomain,$ownerhome);
     if ($env{'request.editurl'} ne '') {
-        ($ownername,$ownerdomain) = 
-            &Apache::loncacc::constructaccess($env{'request.editurl'},$r->dir_config('lonDefDomain'));
+        ($ownername,$ownerdomain,$ownerhome) = 
+            &Apache::lonnet::constructaccess($env{'request.editurl'});
     }
 
     # Breadcrumbs
     &Apache::lonhtmlcommon::clear_breadcrumbs();
     if ($env{'request.role'} =~ /^(au|ca|aa)/) { 
         &Apache::lonhtmlcommon::add_breadcrumb({
-            'text' => 'Construction Space',
-            'href' => &Apache::loncommon::authorspace(),
+            'text' => 'Authoring Space',
+            'href' => &Apache::loncommon::authorspace($env{'request.editurl'}),
         });
     } elsif (($env{'request.course.id'}) && 
              (&Apache::lonnet::allowed('mdc',$env{'request.course.id'}))) {
@@ -68,14 +67,13 @@ sub handler {
     }
 
 # print header
-    $r->print(&Apache::loncommon::start_page("Failed Access to Construction Space",
+    $r->print(&Apache::loncommon::start_page("Failed Access to Authoring Space",
 					     undef,
 					     {'domain' => $ownerdomain,}).
                                              &Apache::lonhtmlcommon::breadcrumbs());
 # figure out what went wrong
 
     if ($ownerdomain) {
-        my $ownerhome=&Apache::lonnet::homeserver($ownername,$ownerdomain);
         if ($ownerhome eq 'no_host') {
             $r->print('<p class="LC_error">'.
                       &mt('Unable to determine home server for this resource: [_1]',
@@ -87,8 +85,8 @@ sub handler {
                 my $switchlink = '/adm/switchserver?otherserver='.$ownerhome.
                                  '&origurl='.&HTML::Entities::encode($env{'request.editurl'},'<>&"');
 	        $r->print('<p class="LC_warning">'.
-                          &mt('The construction space for this resource is located on another server.').
-                          ' <b><tt>'.&Apache::lonnet::hostname($ownerhome).'</b></tt>'.
+                          &mt('The Authoring Space for this resource is located on a different server: [_1]',
+                          '<b><tt>'.&Apache::lonnet::hostname($ownerhome).'</b></tt>').
                           '</p>'.
                           '<p class="LC_error"><a href="'.$switchlink.'">'.
                           &mt('Switch Server').'</a>'.
@@ -162,7 +160,7 @@ sub handler {
                                   '</p>');
                     } else {
                         if (($action eq 'diff') && ($option eq 'cstr')) {
-                            $filename =~ s{^/res/$LONCAPA::domain_re/($LONCAPA::username_re)}{/priv/$1};
+                            $filename =~ s{^/res/}{/priv/};
                         }
                         $r->print('<p class="LC_error">'.
                                   $deniedactions{$action}.'</p><p class="LC_warning">'.
@@ -181,7 +179,7 @@ sub handler {
                       &mt('There is a problem with the filename').' '.
                       '<span class="LC_filename">'.$r->uri.'</span></p>'.
                       '<p class="LC_warning">'.
-                      &mt('You may be attempting to edit a versioned file (files in construction space may not include a version number before the extension).').
+                      &mt('You may be attempting to edit a versioned file (files in Authoring Space may not include a version number before the extension).').
                       '</p>');
         } else {
             $r->print('<p class="LC_error">'.
@@ -193,25 +191,24 @@ sub handler {
                   &mt('There is a problem with the filename').' '.
                   '<span class="LC_filename">'.$env{'request.editurl'}.'</span></p>'.
                   '<p class="LC_warning">'.
-                  &mt('You may be attempting to edit a versioned file (files in construction space may not include a version number before the extension).').
+                  &mt('You may be attempting to edit a versioned file (files in Authoring Space may not include a version number before the extension).').
                   '</p>');
     } else {
         $r->print('<p class="LC_error">'
                  .&mt('You do not have authoring privileges for this resource').' '
                  .'<span class="LC_filename">'.$env{'request.editurl'}.'</span>'
                  .'</p>');
-        my ($realownername) =
-	    ($env{'request.editurl'}=~m{(?:~|priv/|home/)($LONCAPA::username_re)});
+        my ($realownerdom,$realownername) =
+	    ($env{'request.editurl'}=~m{^/priv/($LONCAPA::domain_re)/($LONCAPA::username_re)});
         my $realownerhome=
-	    &Apache::lonnet::homeserver($realownername,
-                                        $r->dir_config('lonDefDomain'));
+	    &Apache::lonnet::homeserver($realownername,$realownerdom);
         unless ($realownerhome eq 'no_host') {
-            my $plainname=&Apache::loncommon::plainname($realownername,$r->dir_config('lonDefDomain'));
-            my $user=$realownername.':'.$r->dir_config('lonDefDomain');
+            my $plainname=&Apache::loncommon::plainname($realownername,$realownerdom);
+            my $user=$realownername.':'.$realownerdom;
             my $userlink=&Apache::loncommon::aboutmewrapper(
                              $plainname.' ('.$user.')'
                             ,$realownername
-                            ,$r->dir_config('lonDefDomain'));
+                            ,$realownerdom);
 	    $r->print('<p>'
                      .&mt('Contact [_1] for access.',$userlink)
                      .'</p>');
