@@ -1,8 +1,7 @@
-
 # The LearningOnline Network with CAPA
 # Handler to upload files into construction space
 #
-# $Id: lonupload.pm,v 1.53.2.1 2011/11/07 13:38:45 raeburn Exp $
+# $Id: lonupload.pm,v 1.67 2015/09/11 20:12:30 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -126,7 +125,6 @@ use Apache::File;
 use File::Copy;
 use File::Basename;
 use Apache::Constants qw(:common :http :methods);
-use Apache::loncacc;
 use Apache::loncommon();
 use Apache::lonnet;
 use HTML::Entities();
@@ -163,7 +161,7 @@ sub upfile_store {
 }
 
 sub phaseone {
-    my ($r,$fn,$uname,$udom,$mode)=@_;
+    my ($r,$fn,$mode,$uname,$udom)=@_;
     my $action = '/adm/upload';
     if ($mode eq 'testbank') {
         $action = '/adm/testbank';
@@ -175,16 +173,14 @@ sub phaseone {
     $env{'form.upfile.filename'}=~s/\\/\//g;
     $env{'form.upfile.filename'}=~s/^.*\/([^\/]+)$/$1/;
     if (!$env{'form.upfile.filename'}) {
-        $r->print('<p class="LC_warning">'.&mt('No upload file specified.').'</p>');
+        $r->print('<p class="LC_warning">'.&mt('No upload file specified.').'</p>'.
+                  &earlyout($fn,$uname,$udom));
         return;
     }
 
-    $fn=~s/\/[^\/]+$//;
-    $fn=~s/([^\/])$/$1\//;
+    # Append the name of the uploaded file
     $fn.=$env{'form.upfile.filename'};
-    $fn=~s/^\///;
     $fn=~s/(\/)+/\//g;
-    #    Fn is the full path to the destination filename.
 
     # Check for illegal filename
     &Debug($r, "Filename for upload: $fn");
@@ -192,20 +188,41 @@ sub phaseone {
         $r->print('<p class="LC_warning">'.&mt('Illegal filename.').'</p>');
         return;
     }
+    # Check if quota exceeded
+    my $filesize = length($env{'form.upfile'});
+    if (!$filesize) {
+        $r->print('<p class="LC_warning">'.
+                  &mt('Unable to upload [_1]. (size = [_2] bytes)',
+                      '<span class="LC_filename">'.$env{'form.upfile.filename'}.'</span>',
+                      $filesize).'<br />'.
+                  &mt('Either the file you attempted to upload was empty, or your web browser was unable to read its contents.').'<br />'.
+                  '</p>'.
+                  &earlyout($fn,$uname,$udom));
+        return;
+    }
+    $filesize = int($filesize/1000); #expressed in kb
+    my $output = &Apache::loncommon::excess_filesize_warning($uname,$udom,'author',
+                                                             $env{'form.upfile.filename'},$filesize,'upload');
+    if ($output) {
+        $r->print($output.&earlyout($fn,$uname,$udom));
+        return;
+    }
 
+# Split part that I can change from the part that I cannot change
+    my ($fn1,$fn2)=($fn=~/^(\/priv\/[^\/]+\/[^\/]+\/)(.*)$/);
     # Display additional options for upload
     # and upload button
     $r->print(
         '<form action="'.$action.'" method="post" name="fileupload">'
        .'<input type="hidden" name="phase" value="two" />'
        .'<input type="hidden" name="datatoken" value="'.&upfile_store.'" />'
-       .'<input type="hidden" name="uploaduname" value="'.$uname.'" />'
     );
     $r->print(
         &Apache::lonhtmlcommon::start_pick_box()
        .&Apache::lonhtmlcommon::row_title(&mt('Save uploaded file as'))
-       .'<span class="LC_filename">/priv/'.$uname.'/</span>'
-       .'<input type="text" size="50" name="filename" value="'.$fn.'" />'
+       .'<span class="LC_filename">'.$fn1.'</span>'
+       .'<input type="hidden" name="filename1" value="'.$fn1.'" />'
+       .'<input type="text" size="50" name="filename2" value="'.$fn2.'" />'
        .&Apache::lonhtmlcommon::row_closure()
        .&Apache::lonhtmlcommon::row_title(&mt('File Type'))
        .'<select name="filetype">'
@@ -242,7 +259,8 @@ sub phaseone {
 }
 
 sub phasetwo {
-    my ($r,$tfn,$uname,$udom,$mode)=@_;
+    my ($r,$fn,$mode)=@_;
+
     my $output;
     my $action = '/adm/upload';
     my $returnflag = '';
@@ -251,12 +269,9 @@ sub phasetwo {
     } elsif ($mode eq 'imsimport') {
         $action = '/adm/imsimport';
     }
-    my $fn='/priv/'.$uname.'/'.$tfn;
     $fn=~s/\/+/\//g;
-    &Debug($r, "Filename is ".$tfn);
-    if ($tfn) {
-	&Debug($r, "Filename for tfn = ".$tfn);
-	my $target='/home/'.$uname.'/public_html'.$tfn;
+    if ($fn) {
+	my $target= $r->dir_config('lonDocRoot').'/'.$fn;
 	&Debug($r, "target -> ".$target);
 #     target is the full filesystem path of the destination file.
 	my $base = &File::Basename::basename($fn);
@@ -378,7 +393,7 @@ sub check_extension {
                         if ($pathchg) {
                             if ($mode eq 'testbank') {
                                 $returnflag = 'embedded';
-                                $result .=  '<p>'.&mt('Or [_1]continue[_2] the testbank import without modifying the references(s).','<a href="javascript:document.testbankForm.submit();">','</a>').'</p>';
+                                $result .=  '<p>'.&mt('Or [_1]continue[_2] the testbank import without modifying the reference(s).','<a href="javascript:document.testbankForm.submit();">','</a>').'</p>';
                             }
                         }
                     }
@@ -401,15 +416,19 @@ sub check_extension {
 
 sub phasethree {
     my ($r,$fn,$uname,$udom,$mode) = @_;
+
     my $action = '/adm/upload'; 
     if ($mode eq 'testbank') {
         $action = '/adm/testbank';
     } elsif ($mode eq 'imsimport') {
         $action = '/adm/imsimport';
     }
-    my $dir_root = '/home/'.$uname.'/public_html';
-    my $url_root = '/priv/'.$uname;
+    my $url_root = "/priv/$udom/$uname";
+    my $dir_root = $r->dir_config('lonDocRoot').$url_root;
     my $path = &File::Basename::dirname($fn);
+    $path =~ s{^\Q$url_root\E}{};
+    my $dirpath = $url_root.$path.'/';
+    $dirpath=~s{/+}{/}g;
     my $filename = &HTML::Entities::encode($env{'form.filename'},'<>&"');
     my $state = &embedded_form_elems('modify_orightml',$filename,$mode).
                 '<input type="hidden" name="phase" value="four" />';
@@ -418,9 +437,9 @@ sub phasethree {
                                             $dir_root,$url_root,undef,
                                             undef,undef,$state,$action);
     if ($mode ne 'imsimport' && $mode ne 'testbank') {
-        $result .= '<br /><h3><a href="'.$url_root.$fn.'">'.
+        $result .= '<br /><h3><a href="'.$fn.'">'.
                   &mt('View main file').'</a></h3>'.
-                  '<h3><a href="'.$url_root.$path.'">'.
+                  '<h3><a href="'.$dirpath.'">'.
                   &mt('Back to Directory').'</a></h3><br />';
     }
     return ($result,$returnflag);
@@ -437,6 +456,7 @@ STATE
 
 sub phasefour {
     my ($r,$fn,$uname,$udom,$mode) = @_;
+
     my $action = '/adm/upload';
     if ($mode eq 'testbank') {
         $action = '/adm/testbank';
@@ -444,38 +464,70 @@ sub phasefour {
         $action = '/adm/imsimport';
     }
     my $result;
-    my $dir_root = '/home/'.$uname.'/public_html';
-    my $url_root = '/priv/'.$uname;
+    my $url_root = "/priv/$udom/$uname";
+    my $dir_root = $r->dir_config('lonDocRoot').$url_root;
     my $path = &File::Basename::dirname($fn);
-    $result .= &Apache::loncommon::modify_html_refs($mode,$path,
-                              $uname,$udom,$dir_root);
+    $path =~ s{^\Q$url_root\E}{};
+    my $dirpath = $url_root.$path.'/';
+    $dirpath=~s{/+}{/}g;
+    my $outcome = 
+        &Apache::loncommon::modify_html_refs($mode,$path,$uname,$udom,$dir_root);
+    $result .= $outcome;
     if ($mode ne 'imsimport' && $mode ne 'testbank') {
-        $result .= '<br /><h3><a href="'.$url_root.$fn.'">'.
+        $result .= '<br /><h3><a href="'.$fn.'">'.
                   &mt('View main file').'</a></h3>'.
-                  '<h3><a href="'.$url_root.$path.'">'.
+                  '<h3><a href="'.$dirpath.'">'.
                   &mt('Back to Directory').'</a></h3><br />';
     }
     return $result;
 }
 
+sub earlyout {
+    my ($fn,$uname,$udom) = @_;
+    if ($fn =~ m{^(/priv/$udom/$uname(?:.*)/)[^/]*}) {
+        return &Apache::lonhtmlcommon::actionbox(
+               ['<a href="'.$1.'">'.&mt('Return to Directory').'</a>']);
+    }
+    return;
+}
+
 # ---------------------------------------------------------------- Main Handler
 sub handler {
 
     my $r=shift;
-
-    my $uname;
-    my $udom;
     my $javascript = '';
-#
-# phase two: re-attach user
-#
-    if ($env{'form.uploaduname'}) {
-	$env{'form.filename'}='/priv/'.$env{'form.uploaduname'}.'/'.
-	    $env{'form.filename'};
+    my $fn=$env{'form.filename'};
+
+    if ($env{'form.filename1'}) {
+       $fn=$env{'form.filename1'}.$env{'form.filename2'};
+    }
+    $fn=~s/\/+/\//g;
+
+    unless ($fn) {
+        $r->log_reason($env{'user.name'}.' at '.$env{'user.domain'}.
+                       ' unspecified filename for upload', $r->filename);
+        return HTTP_NOT_FOUND;
     }
 
+    my ($uname,$udom)=&Apache::lonnet::constructaccess($fn);
+
+    unless (($uname) && ($udom)) {
+        $r->log_reason($uname.' at '.$udom.
+                       ' trying to publish file '.$env{'form.filename'}.
+                       ' - not authorized',
+                       $r->filename);
+        return HTTP_NOT_ACCEPTABLE;
+    }
+
+# ----------------------------------------------------------- Start page output
+
+    &Apache::loncommon::content_type($r,'text/html');
+    $r->send_http_header;
+
     unless ($env{'form.phase'} eq 'two') {
-        $javascript = qq|
+        $javascript = <<"ENDJS";
+<script type="text/javascript">
+// <![CDATA[
 function verifyForm() {
     var mode = document.fileupload.filetype.options[document.fileupload.filetype.selectedIndex].value
     if (mode == "testbank") {
@@ -489,50 +541,21 @@ function verifyForm() {
     }
     document.fileupload.submit();
 }
-	|;
-    }
-    ($uname,$udom)=
-	&Apache::loncacc::constructaccess($env{'form.filename'},
-					  $r->dir_config('lonDefDomain'));
-
-    unless (($uname) && ($udom)) {
-	$r->log_reason($uname.' at '.$udom.
-		       ' trying to publish file '.$env{'form.filename'}.
-		       ' - not authorized', 
-		       $r->filename); 
-	return HTTP_NOT_ACCEPTABLE;
-    }
-    
-    my ($fn,$trailfile);
-    if ($env{'form.filename'}) {
-	$fn=$env{'form.filename'};
-	$fn=~s/^https?\:\/\/[^\/]+\///;
-	$fn=~s/^\///;
-	$fn=~s{(~|priv/)($LONCAPA::username_re)}{};
-	$fn=~s/\/+/\//g;
-        $trailfile = "/home/$uname/public_html/".$trailfile;
-        $trailfile=~s{//+}{/}g;
-    } else {
-	$r->log_reason($env{'user.name'}.' at '.$env{'user.domain'}.
-		       ' unspecified filename for upload', $r->filename); 
-	return HTTP_NOT_FOUND;
+// ]]>
+</script>
+ENDJS
     }
 
-# ----------------------------------------------------------- Start page output
-
-
-    &Apache::loncommon::content_type($r,'text/html');
-    $r->send_http_header;
-
-   $javascript = "<script type=\"text/javascript\">\n//<!--\n".
-	$javascript."\n// --></script>\n";
+    my $londocroot = $r->dir_config('lonDocRoot');
+    my $trailfile = $fn;
+    $trailfile =~ s{^/(priv/)}{$londocroot/$1};
 
     # Breadcrumbs
-    my $brcrum = [{'href' => &Apache::loncommon::authorspace(),
-                   'text' => 'Construction Space'},
+    my $brcrum = [{'href' => &Apache::loncommon::authorspace($fn),
+                   'text' => 'Authoring Space'},
                   {'href' => '/adm/upload',
-                   'text' => 'Upload file to Construction Space'}];
-    $r->print(&Apache::loncommon::start_page('Upload file to Construction Space',
+                   'text' => 'Upload file to Authoring Space'}];
+    $r->print(&Apache::loncommon::start_page('Upload file to Authoring Space',
                                              $javascript,
                                              {'bread_crumbs' => $brcrum,})
              .&Apache::loncommon::head_subbox(
@@ -552,10 +575,10 @@ function verifyForm() {
         my ($output,$rtnflag) = &phasethree($r,$fn,$uname,$udom,'author');
         $r->print($output);
     } elsif ($env{'form.phase'} eq 'two') {
-	my ($output,$returnflag) = &phasetwo($r,$fn,$uname,$udom);
+	my ($output,$returnflag) = &phasetwo($r,$fn);
         $r->print($output);
     } else {
-	&phaseone($r,$fn,$uname,$udom);
+	&phaseone($r,$fn,undef,$uname,$udom);
     }
 
     $r->print(&Apache::loncommon::end_page());
