@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Dynamic plot
 #
-# $Id: lonplot.pm,v 1.175 2014/06/19 17:23:50 raeburn Exp $
+# $Id: lonplot.pm,v 1.177 2017/04/02 21:38:15 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -258,7 +258,7 @@ my %gnuplot_defaults =
 	 test        => sub {$_[0]=~/^(left|right|middle|center)$/},
 	 description => 'Alignment for image in HTML',
 	 edit_type   => 'choice',
-	 choices     => ['left','right','middle']
+	 choices     => ['left','right','middle','center']
 	 },
      texwidth     => {
          default     => '93',
@@ -739,13 +739,19 @@ sub end_gnuplot {
 	$filename = &escape($filename);
 	## return image tag for the plot
 	if ($target eq 'web') {
-	    $result .= <<"ENDIMAGE";
-<img src    = "/cgi-bin/plot.$weboutputformat?file=$filename.data" 
-     width  = "$Apache::lonplot::plot{'width'}"
-     height = "$Apache::lonplot::plot{'height'}"
-     align  = "$Apache::lonplot::plot{'align'}"
-     alt    = "$Apache::lonplot::plot{'alttag'}" />
-ENDIMAGE
+            my $srcatt = "src=\"/cgi-bin/plot.$weboutputformat?file=$filename.data\"";
+            my $widthatt = "width=\"$Apache::lonplot::plot{'width'}\"";
+            my $heightatt = "height=\"$Apache::lonplot::plot{'height'}\"";
+            my $alignatt = "align=\"$Apache::lonplot::plot{'align'}\"";
+            my $altatt = "alt=\"$Apache::lonplot::plot{'alttag'}\"";
+            if ($Apache::lonplot::plot{'align'} eq 'center') {
+                $result .= '<div style="text-align:center">'.
+                    "<img $srcatt $widthatt $heightatt $altatt>".
+                    "</div>\n";
+
+            } else {
+                $result .= "<img $srcatt $widthatt $heightatt $alignatt $altatt>";
+            }
         } elsif ($target eq 'tex') {
 	    &Apache::lonxml::debug(" gnuplot wid = $Apache::lonplot::plot{'width'}");
 	    &Apache::lonxml::debug(" gnuplot ht  = $Apache::lonplot::plot{'height'}");
@@ -753,7 +759,13 @@ ENDIMAGE
 	    &Apache::lonxml::register_ssi("/cgi-bin/plot.gif?file=$filename.data&output=eps");
 	    $result  = "%DYNAMICIMAGE:$Apache::lonplot::plot{'width'}:$Apache::lonplot::plot{'height'}:$Apache::lonplot::plot{'texwidth'}\n";
 	    $result .= '\graphicspath{{'.$tmpdir.'}}'."\n";
+            if ($Apache::lonplot::plot{'align'} eq 'center') {
+                $result .= '\begin{center}';
+            }
 	    $result .= '\includegraphics[width='.$Apache::lonplot::plot{'texwidth'}.' mm]{'.&unescape($filename).'.eps}';
+            if ($Apache::lonplot::plot{'align'} eq 'center') {
+                $result .= '\end{center}';
+            }
 	}
     } elsif ($target eq 'edit') {
 	$result.=&Apache::edit::tag_end($target,$token);
