@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # TeX Conversion Module
 #
-# $Id: lontexconvert.pm,v 1.112.2.4 2014/06/18 06:48:47 raeburn Exp $
+# $Id: lontexconvert.pm,v 1.112.2.6 2016/08/05 21:24:01 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -298,77 +298,35 @@ sub MathJax_converted {
     }
 }
 
-
-sub jsMath_converted {
-    my $texstring=shift;
-    my $tag='span';
-    if (&displaystyle($texstring)) { $tag='div'; }
-    &clean_out_math_mode($texstring);
-    return &jsMath_header().
-	'<'.$tag.' class="math">'.$$texstring.'</'.$tag.'>';
-}
-
-{
-    my @jsMath_sent_header;
-    sub jsMath_reset {
-	undef(@jsMath_sent_header);
-    }
-    sub jsMath_push {
-	push(@jsMath_sent_header,0);
-    }
-    sub jsMath_header {
-	if (!@jsMath_sent_header) {
-	    &Apache::lonnet::logthis("mismatched calls of jsMath_header and jsMath_process");
-	    return '';
-	}
-	return '' if $jsMath_sent_header[-1];
-	$jsMath_sent_header[-1]=1;
-	return
-            '<script type="text/javascript">
-                     function NoFontMessage () {}
-                     jsMath = {Parser: {prototype: {environments: {\'eqnarray*\' :[\'Array\',null,null,\'rcl\',[5/18,5/18],3,\'D\']}}}};
-                   </script>'."\n".
-	    '<script type="text/javascript" src="/adm/jsMath/jsMath.js"></script>'."\n";
-    }
-    sub jsMath_process {
-	my $state = pop(@jsMath_sent_header);
-	return '' if !$state;
-	return "\n".
-	    '<script type="text/javascript">jsMath.Process()</script>'."\n";
-    }
-    sub jsMath_state {
-	my ($level) = @_;
-	return $jsMath_sent_header[$level];
-    }
-}
-
 sub tex_engine {
     if (exists($env{'form.texengine'})) {
 	if ($env{'form.texengine'} ne '') {
+            if (lc($env{'form.texengine'}) eq 'jsmath') {
+                return 'MathJax';
+            }
             return $env{'form.texengine'};
         }
     }    
     if ($env{'request.course.id'}
 	&& exists($env{'course.'.$env{'request.course.id'}.'.texengine'})) {
+        if (lc($env{'course.'.$env{'request.course.id'}.'.texengine'}) eq 'jsmath') {
+            return 'MathJax';
+        }
 	return $env{'course.'.$env{'request.course.id'}.'.texengine'};
     }
     if (exists($env{'environment.texengine'})) {
+        if (lc($env{'environment.texengine'}) eq 'jsmath') {
+            return 'MathJax';
+        }
 	return $env{'environment.texengine'};
     }
     return 'tth';
 }
 
 sub init_math_support {
-    my ($inherit_jsmath) = @_;
     &init_tth();
-    &Apache::lontexconvert::jsMath_push();
-    if (lc(&tex_engine()) eq 'jsmath' ||
-	($inherit_jsmath && &jsMath_state(-2))) {
-	return &Apache::lontexconvert::jsMath_header();
-    }
     &Apache::lontexconvert::MathJax_push();
-    if (lc(&tex_engine()) eq 'mathjax') { # ||
-        #($inherit_jsmath && &jsMath_state(-2))) {
+    if (lc(&tex_engine()) eq 'mathjax') {
         return &Apache::lontexconvert::MathJax_header();
     }
     return;
@@ -430,7 +388,7 @@ sub converted {
     if ($mode =~ /tth/i) {
 	return &tth_converted($string);
     } elsif ($mode =~ /jsmath/i) {
-	return &jsMath_converted($string);
+	return &MathJax_converted($string);
     } elsif ($mode =~ /mathjax/i) {
         return &MathJax_converted($string);
     } elsif ($mode =~ /mimetex/i) {
@@ -579,7 +537,7 @@ sub postprocess_algebra {
     # $string =~s/\\fun/ /g;
 
     # sqrt(3,4) means the 4 root of 3
-    $string =~s/\\sqrt{([^,]+),([^\}]+)}/\\sqrt[$2]{$1}/gs;
+    $string =~s/\\sqrt\{([^,]+),([^\}]+)}/\\sqrt[$2]{$1}/gs;
 
     # log(3,4) means the log base 4 of 3
     $string =~s/\\log\\left\((.+?),(.+?)\\right\)/\\log_{$2}\\left($1\\right)/gs;
@@ -641,14 +599,10 @@ Header
 =item displaystyle()
 
 
-=item jsMath_converted()
-
 =item MathJax_converted()
-        - Mimics the jsMath functionality
 
 =item tex_engine()
 
-
 =item init_math_support()
 
 =item mimetex_valign()
