@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # XML Parser Module 
 #
-# $Id: lonxml.pm,v 1.531.2.19 2015/04/06 17:02:33 raeburn Exp $
+# $Id: lonxml.pm,v 1.531.2.22 2016/09/16 14:20:47 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -440,9 +440,9 @@ sub latex_special_symbols {
     } else {
 	$string=~s/\\/\\ensuremath{\\backslash}/g;
 	$string=~s/\\\%|\%/\\\%/g;
-	$string=~s/\\{|{/\\{/g;
+	$string=~s/\\\{|{/\\{/g;
 	$string=~s/\\}|}/\\}/g;
-	$string=~s/\\ensuremath\\{\\backslash\\}/\\ensuremath{\\backslash}/g;
+	$string=~s/\\ensuremath\\\{\\backslash\\}/\\ensuremath{\\backslash}/g;
 	$string=~s/\\\$|\$/\\\$/g;
 	$string=~s/\\\_|\_/\\\_/g;
         $string=~s/([^\\]|^)(\~|\^)/$1\\$2\\strut /g;
@@ -1623,7 +1623,6 @@ sub renderingoptions {
                (''        => '',
                 'tth'     => 'tth (TeX to HTML)',
                 'MathJax' => 'MathJax',
-  		'jsMath'  => 'jsMath',
                 'mimetex' => 'mimetex (Convert to Images)')}).
      '</span>';
     return $output;
@@ -1736,11 +1735,11 @@ $initialize
         $xml_help
       </td></tr>
     </table>
-    <div class="LC_edit_problem_discards">
+    <div>
       <input type="submit" name="discardview" accesskey="d" value="$lt{'dv'}" />
       $undo $htmlerror $deps_button $dragmath_button
     </div>
-    <div class="LC_edit_problem_saves">
+    <div style="float:right">
       <input type="submit" name="savethisfile" accesskey="s" value="$lt{'st'}" />
       <input type="submit" name="viewmode" accesskey="v" value="$lt{'vi'}" />
     </div>
