@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Page Handler
 #
-# $Id: lonpage.pm,v 1.108 2015/03/11 19:55:44 raeburn Exp $
+# $Id: lonpage.pm,v 1.111.2.4 2016/10/29 13:47:21 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -40,6 +40,7 @@ use Apache::lonhtmlcommon;
 use Apache::lonxml();
 use Apache::lonlocal;
 use Apache::lonmenu;
+use Apache::lonhomework;
 use HTML::TokeParser;
 use GDBM_File;
 use Apache::lonsequence;
@@ -182,11 +183,24 @@ sub handler {
   if (($env{'request.course.fn'}) && (!$env{'form.forceselect'})) {
       my $fn=$env{'request.course.fn'};
       if (-e "$fn.db") {
+          my %buttonshide;
           if (tie(%hash,'GDBM_File',"$fn.db",&GDBM_READER(),0640)) {
 # ------------------------------------------------------------------- Hash tied
               my $firstres=$hash{'map_start_'.$requrl};
               my $lastres=$hash{'map_finish_'.$requrl};
               if (($firstres) && ($lastres)) {
+# ------------------------------------------------------------- Countdown Timer
+                  my $now = time;
+                  my ($pagefirstaccess,%hastimeleft,%countdowndisp);
+                  my ($pagesymb,$courseid,$domain,$name)=&Apache::lonnet::whichuser();
+                  if ($pagesymb && ($courseid ne '') && ($domain ne '') && ($name ne '')) {
+                      my %times=&Apache::lonnet::get('firstaccesstimes',
+                                                     [$courseid."\0".$pagesymb],
+                                                     $domain,$name);
+                      if ($times{$courseid."\0".$pagesymb} =~ /^\d+$/) {
+                          $pagefirstaccess = $times{$courseid."\0".$pagesymb};
+                      }
+                  }
 # ----------------------------------------------------------------- Render page
 
                   @rows=();
@@ -216,6 +230,7 @@ sub handler {
                   my $contents=0;
                   my $nforms=0;
                   my $nuploads=0;
+                  my $ntimers=0;
                   my %turninpaths;
                   my %multiresps;
                   my $turninparent;
@@ -246,11 +261,17 @@ sub handler {
                       $lcm*=($#colcont+1)/euclid($lcm,($#colcont+1));
                       foreach (@colcont) {
                           my $src=$hash{'src_'.$_};
+                          my $plainsrc = $src;
                           my ($extension)=($src=~/\.(\w+)$/);
 			  $cellexternal{$_}=($hash{'ext_'.$_} eq 'true:');
 			  if ($hash{'encrypted_'.$_}) {
 			      $src=&Apache::lonenc::encrypted($src);
 			  }
+                          my ($mapid,$resid)=split(/\./,$_);
+                          my $symb=&Apache::lonnet::encode_symb($hash{'map_id_'.$mapid},$resid,$src);
+                          unless ($env{'request.role.adv'}) {
+                              $buttonshide{$symb} = &Apache::lonnet::EXT("resource.0.buttonshide",$symb);
+                          }
                           $cellemb{$_}=
 			      &Apache::loncommon::fileembstyle($extension);
                           if ($cellexternal{$_}) {
@@ -261,9 +282,6 @@ ENDEXT
                               }
                           } elsif ($cellemb{$_} eq 'ssi') {
 # --------------------------------------------------------- This is an SSI cell
-			      my ($mapid,$resid)=split(/\./,$_);
-			      my $symb=&Apache::lonnet::encode_symb($hash{'map_id_'.$mapid},$resid,$src);
-			      
 			      my $prefix=$_.'_';
                               my $idprefix= join('_',($mapid,$resid,''));
                               my %posthash=('request.prefix' => $prefix,
@@ -298,11 +316,14 @@ ENDEXT
 				      $posthash{'all_submit'}='yes';
 				  }
 			      }
+                              if ($env{'environment.remote'} eq 'on') {
+                                  $posthash{'inhibitmenu'} = 'yes';
+                              }
                               my $output=Apache::lonnet::ssi($src,%posthash);
 			      $output=~s|//(\s*<!--)? BEGIN LON-CAPA Internal.+?// END LON-CAPA Internal\s*(-->)?\s||gs;
                               if (($target eq 'tex') || ($target eq 'tex_answer')) {
-				  $output =~ s/^([^&]+)\\begin{document}//;
-				  $output =~ s/\\end{document}//;
+				  $output =~ s/^([^&]+)\\begin\{document}//;
+				  $output =~ s/\\end\{document}//;
 #				  $output = '\parbox{\minipagewidth}{ '.$output.' }';
                                   #some additional cleanup necessary for LateX (due to limitations of table environment 
 				  $output =~ s/(\\vskip\s*\d+mm)\s*(\\\\)+/$1/g;
@@ -369,16 +390,26 @@ ENDEXT
                               }
                               $output=~s/\<\/body\>.*//si;
                               if ($output=~/\<form/si) {
+                                  my $hastimer; 
 				  $nforms++;
                                   $output=~s/\<form[^\>]*\>//gsi;
                                   $output=~s/\<\/form[^\>]*\>//gsi;
                                   if ($output=~/\<input[^\>]+name\s*=\s*[\'\"]*HWFILE/) {
                                       $nuploads++;
                                   }
+                                  if ($output=~/\<input[^\>]+name\s*=\s*[\'\"]*accessbutton/) {
+                                      $ntimers++;
+                                      $hastimer = 1;
+                                  }
                                   $output=~
 				      s/\<((?:input|select|button|textarea)[^\>]+)name\s*\=\s*[\'\"]*([^\'\"]+)[\'\"]*([^\>]*)\>/\<$1 name="$prefix$2" $3\>/gsi;
                                   $output=~
                                       s/\<((?:input|select|button|textarea)[^\>]+)id\s*\=\s*[\'\"]*([^\'\"]+)[\'\"]*([^\>]*)\>/\<$1 id="$idprefix$2" $3\>/gsi;
+                                  if ($hastimer) {
+                                      $output=~
+                                          s/\<(input[^\>]+name=\Q"$prefix\Eaccessbutton"[^\>]+)(?:\Qdocument.markaccess.submit();\E)([^\>]*)\>/\<$1pageTimer(this.form,'$prefix')$2\>/gsi;
+                                      $output=~  s/\<(input[^\>]+name=\Q"$prefix\Emarkaccess"[^\>]+value=["'])(?:yes)(['"][^\>]*)\>/\<$1$2\>/gsi;
+                                  }
                                   if ($matheditor eq 'dragmath') {
                                       $output=~
                                           s/(\Qjavascript:LC_mathedit_\E)(HWVAL_)([^'"]+?)(\(['"]*)(\QHWVAL_\E\3['"]\)\;void\(0\)\;)/$1$idprefix$2$3$4$idprefix$5/g;
@@ -406,6 +437,59 @@ ENDEXT
                                       s/\<((?:input|select)[^\>]+\Qjavascript:setSubmittedPart\E)\(\s*[\'\"]([^\'\"]+)[\'\"]*\s*\)/\<$1('$2','$prefix')/gsi;
                                   $output=~
                                       s/\<(input[^\>]+\Qonfocus=\"javascript:disableAutoComplete\E)\(\'([^\']+)\'\)(;\")/\<$1('$idprefix$2')$3/gsi;
+                                  unless ($hastimer) {
+                                      if ($plainsrc =~ /$LONCAPA::assess_re/) {
+                                          %Apache::lonhomework::history =
+                                              &Apache::lonnet::restore($symb,$courseid,$domain,$name);
+                                          my $type = 'problem';
+                                          if ($extension eq 'task') {
+                                              $type = 'Task';
+                                          }
+                                          my ($status,$accessmsg,$slot_name,$slot) =
+                                              &Apache::lonhomework::check_slot_access('0',$type,$symb);
+                                          undef(%Apache::lonhomework::history);
+                                          my $probstatus = &Apache::lonnet::EXT("resource.0.problemstatus",$symb);
+                                          if (($status eq 'CAN_ANSWER') || (($status eq 'CANNOT_ANSWER') && 
+                                              (($probstatus eq 'no') || ($probstatus eq 'no_feedback_ever')))) {
+                                              my ($slothastime,$timerhastime);
+                                              if ($slot_name ne '') {
+                                                  if (ref($slot) eq 'HASH') {
+                                                      if (($slot->{'starttime'} < $now) &&
+                                                          ($slot->{'endtime'} > $now)) {
+                                                          $slothastime = $now - $slot->{'endtime'};
+                                                      }
+                                                  }
+                                              }
+                                              my $duedate = &Apache::lonnet::EXT("resource.0.duedate",$symb);
+                                              my @interval=&Apache::lonnet::EXT("resource.0.interval",$symb);
+                                              if (@interval > 1) {
+                                                  my $first_access=&Apache::lonnet::get_first_access($interval[1],$symb);
+                                                  if ($first_access > 0) {
+                                                      my $timeremains = $first_access+$interval[0] - $now;
+                                                      if ($timeremains > 0) {
+                                                          $timerhastime = $timeremains;
+                                                      }
+                                                  }
+                                              }
+                                              if (($duedate && $duedate > $now) ||
+                                                  (!$duedate && $timerhastime > 0) ||
+                                                  ($slot_name ne '' && $slothastime)) {
+                                                  if ((@interval > 1 && $timerhastime) ||
+                                                      ($type eq 'Task' && $slothastime)) {
+                                                      $countdowndisp{$symb} = 'inline';
+                                                      if ((@interval > 1) && ($timerhastime)) {
+                                                          $hastimeleft{$symb} = $timerhastime;
+                                                      } else {
+                                                          $hastimeleft{$symb} = $slothastime;
+                                                      }
+                                                  } else {
+                                                      $hastimeleft{$symb} = $duedate - $now;
+                                                      $countdowndisp{$symb} = 'none';
+                                                  }
+                                              }
+                                          }
+                                      }
+                                  }
                               }
                               $thisdir=~s/\/[^\/]*$//;
 			      foreach (@rlinks) {
@@ -431,7 +515,7 @@ ENDEXT
                       &Apache::loncommon::content_type($r,'text/html');
                       $r->send_http_header;
                       $r->print(&Apache::loncommon::start_page(undef,undef,
-							       {'force_register' => 1,}));
+							       {'force_register' => 1}));
                       $r->print(&mt('This page is either empty or it only contains resources that are currently hidden').'. ');
                       $r->print('<br /><br />'.&mt('Please use the LON-CAPA navigation arrows to move to another item in the course').
 				&Apache::loncommon::end_page());
@@ -462,10 +546,64 @@ ENDEXT
                               );
                               $allscript .= &Apache::lonhtmlcommon::htmlareaselectactive(\%textarea_args);
                           }
+                          if ($ntimers) {
+                              $allscript .= '<script type="text/javascript">'."\n".
+                                            '// <![CDATA['."\n".
+                                            'function pageTimer(form,prefix) {'."\n".
+                                            "   form.elements[prefix+'markaccess'].value = 'yes';\n".
+                                            "   form.submit();\n".
+                                            '}'."\n".
+                                            '// ]]>'.
+                                            "\n</script>\n";
+                          }
+                          if (keys(%hastimeleft)) {
+                              my (%uniquetimes,%uniquedisplays);
+                              foreach my $item (values(%hastimeleft)) {
+                                  if (exists($uniquetimes{$item})) {
+                                      $uniquetimes{$item} ++; 
+                                  } else {
+                                      $uniquetimes{$item} = 1;
+                                  }
+                              }
+                              if (keys(%uniquetimes) == 1) {
+                                  my (%uniquedisplays,%uniquedones,$currdisp);
+                                  if (keys(%countdowndisp)) {
+                                      foreach my $item (values(%countdowndisp)) {
+                                          if (exists($uniquedisplays{$item})) {
+                                              $uniquedisplays{$item} ++;
+                                          } else {
+                                              $uniquedisplays{$item} = 1;
+                                          }
+                                      }
+                                      my @countdowndisplay = keys(%uniquedisplays);
+                                      if (scalar(@countdowndisplay) == 1) {
+                                          $currdisp = $countdowndisplay[0];
+                                      }
+                                  }
+                                  &add_countdown_timer($currdisp);
+                              }
+                          }
+                          my $pagebuttonshide;
+                          if (keys(%buttonshide)) {
+                              my %uniquebuttonhide;
+                              foreach my $item (values(%buttonshide)) {
+                                  if (exists($uniquebuttonhide{$item})) {
+                                      $uniquebuttonhide{$item} ++;
+                                  } else {
+                                      $uniquebuttonhide{$item} = 1;
+                                  }
+                              }
+                              if (keys(%uniquebuttonhide) == 1) {
+                                  if (lc((keys(%uniquebuttonhide))[0]) eq 'yes') {
+                                      $pagebuttonshide = 'yes';
+                                  }
+                              }
+                          }
 # ------------------------------------------------------------------ Start body
 			  $r->print(&Apache::loncommon::start_page(undef,$allscript,
 								   {'force_register' => 1,
-								    'bgcolor'        => '#ffffff',}));
+								    'bgcolor'        => '#ffffff',
+								    'hide_buttons'   => $pagebuttonshide}));
 # ------------------------------------------------------------------ Start form
 			  if ($nforms) {
 			      my $fmtag = '<form name="lonhomework" method="post"  enctype="multipart/form-data"';
@@ -511,7 +649,7 @@ ENDEXT
                           my $avespan=$lcm/($#colcont+1);
                           for ($j=0;$j<=$#colcont;$j++) {
                               my $rid=$colcont[$j];
-			      my $metainfo =&get_buttons(\%hash,$rid).'<br />';
+			      my $metainfo =&get_buttons(\%hash,$rid,\%buttonshide).'<br />';
 			    unless (($target eq 'tex') || ($target eq 'tex_answer')) {
 				$r->print('<td colspan="'.$avespan.'"');
 			    }
@@ -593,6 +731,10 @@ ENDEXT
                           my $class;
                           if ($nforms > 1) {
                               $class = ' class="LC_hwk_submit"';
+                              if ($ntimers) {
+                                  $nforms = 1;
+                                  $class = '';
+                              }
                           }
                           $r->print(
 	                  '<input name="all_submit" value="'.&mt('Submit All').'" type="'.
@@ -635,7 +777,7 @@ ENDEXT
 }
 
 sub get_buttons {
-    my ($hash,$rid) = @_;
+    my ($hash,$rid,$buttonshide) = @_;
 
     my $metainfo = '';
     my $esrc=&Apache::lonnet::declutter($hash->{'src_'.$rid});
@@ -643,6 +785,11 @@ sub get_buttons {
     my $symb=&Apache::lonnet::encode_symb($hash->{'map_id_'.$mapid},
 					  $resid,
 					  $hash->{'src_'.$rid});
+    unless ($env{'request.role.adv'}) {
+        if ($buttonshide->{$symb} eq 'yes') {
+            return;
+        }
+    }
     if ($hash->{'encrypted_'.$rid}) {
 	$symb=&Apache::lonenc::encrypted($symb);
 	$esrc=&Apache::lonenc::encrypted($esrc);
@@ -723,6 +870,35 @@ sub get_buttons {
     return $metainfo;
 }
 
+sub add_countdown_timer {
+    my ($currdisp) = @_;
+    my ($collapse,$expand,$alttxt,$title);
+    if ($currdisp eq 'inline') {
+        $collapse = '&#9658;&nbsp;';
+    } else {
+        $expand = '&#9668;&nbsp;';
+    }
+    unless ($env{'environment.icons'} eq 'iconsonly') {
+        $alttxt = &mt('Timer');
+        $title = $alttxt.'&nbsp;';
+    }
+    my $desc = &mt('Countdown to due date/time');
+    my $output = <<END;
+<a href="javascript:toggleCountdown();" class="LC_menubuttons_link">
+<span id="ddcountcollapse" class="LC_menubuttons_inline_text">
+$collapse
+</span></a>
+<span id="duedatecountdown" class="LC_menubuttons_inline_text" style="display: $currdisp;"></span>
+<a href="javascript:toggleCountdown();" class="LC_menubuttons_link">
+<span id="ddcountexpand" class="LC_menubuttons_inline_text" >$expand</span>
+<img src="/res/adm/pages/timer.png" title="$desc" class="LC_icon" alt="$alttxt" /><span class="LC_menubuttons_inline_text">$title</span></a>
+END
+    &Apache::lonhtmlcommon::clear_breadcrumb_tools();
+    &Apache::lonhtmlcommon::add_breadcrumb_tool('tools',$output);
+    return;
+}
+
+
 1;
 __END__
 
