@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Set parameters inside of the RAT
 #
-# $Id: lonratparms.pm,v 1.28 2009/04/23 17:26:27 bisitz Exp $
+# $Id: lonratparms.pm,v 1.29 2011/12/08 22:11:48 www Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -84,18 +84,12 @@ sub handler {
     my $js = (<<ENDHEADER);
 <script type="text/javascript">
 
-    function pclose() {
-        parmwin=window.open("/adm/rat/empty.html","LONCAPAparms",
-                 "height=350,width=350,scrollbars=no,menubar=no");
-        parmwin.close();
-    }
-
     $pjump_def
 
     function stpr() {
         eval("document.parameters."+document.parameters.pres_marker.value+
             ".value=document.parameters.pres_value.value");
-        pclose();
+        modalWindow.close();
     }
 
 
